import requests
from cacheout import Cache
import time

class Client:
    def __init__(self, username, api_key, is_production=False, cache_enabled=True):
        '''
        :param username: user name for flight aware api
        :param api_key: api key for flight aware api
        '''

        self.FXML_URL = "https://flightxml.flightaware.com/json/FlightXML3/"
        self.authentication_info = (username, api_key)
        self.is_production = is_production
        self.cache_enabled = cache_enabled

        self.stubbed_find_flights_with_airline_info_response = "{'FlightInfoStatusResult': {'next_offset': -1, 'flights': [{'ident': 'DAL127', 'faFlightID': 'DAL127-1560500400-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 28560, 'filed_airspeed_kts': 377, 'distance_filed': 3583, 'filed_departure_time': {'epoch': 1560673200, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:20AM', 'date': '06/16/2019', 'localtime': 1560680400}, 'estimated_departure_time': {'epoch': 1560673800, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:30AM', 'date': '06/16/2019', 'localtime': 1560681000}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560701760, 'tz': 'EDT', 'dow': 'Sunday', 'time': '12:16PM', 'date': '06/16/2019', 'localtime': 1560687360}, 'estimated_arrival_time': {'epoch': 1560702360, 'tz': 'EDT', 'dow': 'Sunday', 'time': '12:26PM', 'date': '06/16/2019', 'localtime': 1560687960}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560414000-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N841MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26280, 'route': 'ZMR UN976 ARDID ARMED 4400N/02000W 4600N/03000W 4700N/04000W NATJ DOVEY N20B SAILE PLYMM PARCH3', 'filed_altitude': 330, 'display_filed_altitude': '33,000 feet', 'filed_airspeed_kts': 471, 'distance_filed': 3583, 'filed_departure_time': {'epoch': 1560586800, 'tz': 'CEST', 'dow': 'Saturday', 'time': '10:20AM', 'date': '06/15/2019', 'localtime': 1560594000}, 'estimated_departure_time': {'epoch': 1560587400, 'tz': 'CEST', 'dow': 'Saturday', 'time': '10:30AM', 'date': '06/15/2019', 'localtime': 1560594600}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560613080, 'tz': 'EDT', 'dow': 'Saturday', 'time': '11:38AM', 'date': '06/15/2019', 'localtime': 1560598680}, 'estimated_arrival_time': {'epoch': 1560613719, 'tz': 'EDT', 'dow': 'Saturday', 'time': '11:48AM', 'date': '06/15/2019', 'localtime': 1560599319}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 639, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560346518-airline-0473', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560327600-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N843MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26880, 'route': 'SUPRY N106B VITOL PLYMM PARCH3', 'filed_altitude': 280, 'display_filed_altitude': '28,000 feet', 'filed_airspeed_kts': 467, 'distance_filed': 3618, 'filed_departure_time': {'epoch': 1560500400, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:20AM', 'date': '06/14/2019', 'localtime': 1560507600}, 'estimated_departure_time': {'epoch': 1560501236, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:33AM', 'date': '06/14/2019', 'localtime': 1560508436}, 'actual_departure_time': {'epoch': 1560501236, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:33AM', 'date': '06/14/2019', 'localtime': 1560508436}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560527280, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:48AM', 'date': '06/14/2019', 'localtime': 1560512880}, 'estimated_arrival_time': {'epoch': 1560528420, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:07PM', 'date': '06/14/2019', 'localtime': 1560514020}, 'actual_arrival_time': {'epoch': 1560528420, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:07PM', 'date': '06/14/2019', 'localtime': 1560514020}, 'arrival_delay': -1320, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560260106-airline-0038', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560241200-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N838MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26760, 'route': 'ELSIR N316A TUSKY PLYMM PARCH3', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 473, 'distance_filed': 3641, 'filed_departure_time': {'epoch': 1560414000, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:20AM', 'date': '06/13/2019', 'localtime': 1560421200}, 'estimated_departure_time': {'epoch': 1560414841, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:34AM', 'date': '06/13/2019', 'localtime': 1560422041}, 'actual_departure_time': {'epoch': 1560414841, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:34AM', 'date': '06/13/2019', 'localtime': 1560422041}, 'departure_delay': -540, 'filed_arrival_time': {'epoch': 1560440760, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:46AM', 'date': '06/13/2019', 'localtime': 1560426360}, 'estimated_arrival_time': {'epoch': 1560442260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:11PM', 'date': '06/13/2019', 'localtime': 1560427860}, 'actual_arrival_time': {'epoch': 1560442260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:11PM', 'date': '06/13/2019', 'localtime': 1560427860}, 'arrival_delay': -600, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560173691-airline-0344', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560154800-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N837MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26640, 'route': 'ZMR UN976 ARDID ARMED 4400N/02000W 4600N/03000W 4700N/04000W NATJ DOVEY N20B SAILE PLYMM PARCH3', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 470, 'distance_filed': 3669, 'filed_departure_time': {'epoch': 1560327600, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:20AM', 'date': '06/12/2019', 'localtime': 1560334800}, 'estimated_departure_time': {'epoch': 1560329188, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:46AM', 'date': '06/12/2019', 'localtime': 1560336388}, 'actual_departure_time': {'epoch': 1560329188, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:46AM', 'date': '06/12/2019', 'localtime': 1560336388}, 'departure_delay': -60, 'filed_arrival_time': {'epoch': 1560354240, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '11:44AM', 'date': '06/12/2019', 'localtime': 1560339840}, 'estimated_arrival_time': {'epoch': 1560356160, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:16PM', 'date': '06/12/2019', 'localtime': 1560341760}, 'actual_arrival_time': {'epoch': 1560356160, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:16PM', 'date': '06/12/2019', 'localtime': 1560341760}, 'arrival_delay': -540, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560087328-airline-0399', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1560068400-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N830MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27960, 'route': 'PLYMM PARCH3', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 478, 'distance_filed': 3597, 'filed_departure_time': {'epoch': 1560241200, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:20AM', 'date': '06/11/2019', 'localtime': 1560248400}, 'estimated_departure_time': {'epoch': 1560242184, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:36AM', 'date': '06/11/2019', 'localtime': 1560249384}, 'actual_departure_time': {'epoch': 1560242184, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:36AM', 'date': '06/11/2019', 'localtime': 1560249384}, 'departure_delay': -180, 'filed_arrival_time': {'epoch': 1560269160, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:06PM', 'date': '06/11/2019', 'localtime': 1560254760}, 'estimated_arrival_time': {'epoch': 1560269783, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:16PM', 'date': '06/11/2019', 'localtime': 1560255383}, 'actual_arrival_time': {'epoch': 1560269783, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:16PM', 'date': '06/11/2019', 'localtime': 1560255383}, 'arrival_delay': -540, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1560000913-airline-0222', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559982000-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N832MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26700, 'route': 'PLYMM PARCH3', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 3597, 'filed_departure_time': {'epoch': 1560154800, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:20AM', 'date': '06/10/2019', 'localtime': 1560162000}, 'estimated_departure_time': {'epoch': 1560156746, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:52AM', 'date': '06/10/2019', 'localtime': 1560163946}, 'actual_departure_time': {'epoch': 1560156746, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:52AM', 'date': '06/10/2019', 'localtime': 1560163946}, 'departure_delay': 240, 'filed_arrival_time': {'epoch': 1560181500, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:45AM', 'date': '06/10/2019', 'localtime': 1560167100}, 'estimated_arrival_time': {'epoch': 1560183120, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:12PM', 'date': '06/10/2019', 'localtime': 1560168720}, 'actual_arrival_time': {'epoch': 1560183120, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:12PM', 'date': '06/10/2019', 'localtime': 1560168720}, 'arrival_delay': -960, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559914500-airline-0338', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559895600-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N844MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26520, 'route': 'NICSO N234A TUSKY PLYMM PARCH3', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 468, 'distance_filed': 3607, 'filed_departure_time': {'epoch': 1560068400, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:20AM', 'date': '06/09/2019', 'localtime': 1560075600}, 'estimated_departure_time': {'epoch': 1560069387, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:36AM', 'date': '06/09/2019', 'localtime': 1560076587}, 'actual_departure_time': {'epoch': 1560069387, 'tz': 'CEST', 'dow': 'Sunday', 'time': '10:36AM', 'date': '06/09/2019', 'localtime': 1560076587}, 'departure_delay': -600, 'filed_arrival_time': {'epoch': 1560094920, 'tz': 'EDT', 'dow': 'Sunday', 'time': '11:42AM', 'date': '06/09/2019', 'localtime': 1560080520}, 'estimated_arrival_time': {'epoch': 1560095705, 'tz': 'EDT', 'dow': 'Sunday', 'time': '11:55AM', 'date': '06/09/2019', 'localtime': 1560081305}, 'actual_arrival_time': {'epoch': 1560095705, 'tz': 'EDT', 'dow': 'Sunday', 'time': '11:55AM', 'date': '06/09/2019', 'localtime': 1560081305}, 'arrival_delay': -1980, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559828094-airline-0343', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559809200-schedule-0003', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N840MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27420, 'route': 'ZMR UN733 DESAT STG KOPAS 4400N/01500W 4400N/02000W 4400N/03000W 4400N/04000W 4400N/05000W RAFIN N88A TUSKY PLYMM PARCH3', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 470, 'distance_filed': 3669, 'filed_departure_time': {'epoch': 1559982000, 'tz': 'CEST', 'dow': 'Saturday', 'time': '10:20AM', 'date': '06/08/2019', 'localtime': 1559989200}, 'estimated_departure_time': {'epoch': 1559985351, 'tz': 'CEST', 'dow': 'Saturday', 'time': '11:15AM', 'date': '06/08/2019', 'localtime': 1559992551}, 'actual_departure_time': {'epoch': 1559985351, 'tz': 'CEST', 'dow': 'Saturday', 'time': '11:15AM', 'date': '06/08/2019', 'localtime': 1559992551}, 'departure_delay': 1251, 'filed_arrival_time': {'epoch': 1560009420, 'tz': 'EDT', 'dow': 'Saturday', 'time': '11:57AM', 'date': '06/08/2019', 'localtime': 1559995020}, 'estimated_arrival_time': {'epoch': 1560013020, 'tz': 'EDT', 'dow': 'Saturday', 'time': '12:57PM', 'date': '06/08/2019', 'localtime': 1559998620}, 'actual_arrival_time': {'epoch': 1560013020, 'tz': 'EDT', 'dow': 'Saturday', 'time': '12:57PM', 'date': '06/08/2019', 'localtime': 1559998620}, 'arrival_delay': 840, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559741677-airline-0041', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559722800-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N835MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27600, 'route': 'ZMR UN976 ARDID ARMED 4300N/02000W 4300N/03000W 4300N/04000W 4300N/05000W JEBBY CARAC N26B VITOL PLYMM PARCH3', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 481, 'distance_filed': 3649, 'filed_departure_time': {'epoch': 1559895600, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:20AM', 'date': '06/07/2019', 'localtime': 1559902800}, 'estimated_departure_time': {'epoch': 1559896816, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:40AM', 'date': '06/07/2019', 'localtime': 1559904016}, 'actual_departure_time': {'epoch': 1559896816, 'tz': 'CEST', 'dow': 'Friday', 'time': '10:40AM', 'date': '06/07/2019', 'localtime': 1559904016}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1559923200, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:00PM', 'date': '06/07/2019', 'localtime': 1559908800}, 'estimated_arrival_time': {'epoch': 1559925254, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:34PM', 'date': '06/07/2019', 'localtime': 1559910854}, 'actual_arrival_time': {'epoch': 1559925254, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:34PM', 'date': '06/07/2019', 'localtime': 1559910854}, 'arrival_delay': 720, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559649927-airline-0156', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559636400-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N842MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27780, 'route': 'NANSO N80A WHALE PLYMM PARCH3', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 479, 'distance_filed': 3605, 'filed_departure_time': {'epoch': 1559809200, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:20AM', 'date': '06/06/2019', 'localtime': 1559816400}, 'estimated_departure_time': {'epoch': 1559810016, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:33AM', 'date': '06/06/2019', 'localtime': 1559817216}, 'actual_departure_time': {'epoch': 1559810016, 'tz': 'CEST', 'dow': 'Thursday', 'time': '10:33AM', 'date': '06/06/2019', 'localtime': 1559817216}, 'departure_delay': 60, 'filed_arrival_time': {'epoch': 1559836980, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:03PM', 'date': '06/06/2019', 'localtime': 1559822580}, 'estimated_arrival_time': {'epoch': 1559838120, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:22PM', 'date': '06/06/2019', 'localtime': 1559823720}, 'actual_arrival_time': {'epoch': 1559838120, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:22PM', 'date': '06/06/2019', 'localtime': 1559823720}, 'arrival_delay': 1260, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559539582-airline-0340', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559539582-airline-0634', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N826MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27180, 'route': 'PLYMM PARCH3', 'filed_altitude': 280, 'display_filed_altitude': '28,000 feet', 'filed_airspeed_kts': 474, 'distance_filed': 3597, 'filed_departure_time': {'epoch': 1559723400, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:30AM', 'date': '06/05/2019', 'localtime': 1559730600}, 'estimated_departure_time': {'epoch': 1559723862, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:37AM', 'date': '06/05/2019', 'localtime': 1559731062}, 'actual_departure_time': {'epoch': 1559723862, 'tz': 'CEST', 'dow': 'Wednesday', 'time': '10:37AM', 'date': '06/05/2019', 'localtime': 1559731062}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1559750580, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:03PM', 'date': '06/05/2019', 'localtime': 1559736180}, 'estimated_arrival_time': {'epoch': 1559751840, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:24PM', 'date': '06/05/2019', 'localtime': 1559737440}, 'actual_arrival_time': {'epoch': 1559751840, 'tz': 'EDT', 'dow': 'Wednesday', 'time': '12:24PM', 'date': '06/05/2019', 'localtime': 1559737440}, 'arrival_delay': -240, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559453201-airline-0416', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559453201-airline-0052', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N833MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27420, 'route': 'ZMR UN976 ARDID ARMED 4300N/02000W 4300N/03000W 4300N/04000W 4300N/05000W JEBBY CARAC N28B WHALE PLYMM PARCH3', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 473, 'distance_filed': 3641, 'filed_departure_time': {'epoch': 1559637000, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:30AM', 'date': '06/04/2019', 'localtime': 1559644200}, 'estimated_departure_time': {'epoch': 1559637196, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:33AM', 'date': '06/04/2019', 'localtime': 1559644396}, 'actual_departure_time': {'epoch': 1559637196, 'tz': 'CEST', 'dow': 'Tuesday', 'time': '10:33AM', 'date': '06/04/2019', 'localtime': 1559644396}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1559664420, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:07PM', 'date': '06/04/2019', 'localtime': 1559650020}, 'estimated_arrival_time': {'epoch': 1559664360, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:06PM', 'date': '06/04/2019', 'localtime': 1559649960}, 'actual_arrival_time': {'epoch': 1559664360, 'tz': 'EDT', 'dow': 'Tuesday', 'time': '12:06PM', 'date': '06/04/2019', 'localtime': 1559649960}, 'arrival_delay': -1500, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'inbound_faFlightID': 'DAL108-1559366771-airline-0085', 'adhoc': False}, {'ident': 'DAL127', 'faFlightID': 'DAL127-1559366771-airline-0230', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '127', 'tailnumber': 'N844MH', 'type': 'Form_Airline', 'codeshares': 'AFR3668,AEA3391,KLM6127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEMD', 'city': 'Madrid', 'alternate_ident': 'MAD', 'airport_name': \"Barajas Int'l\"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': 'JFK', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 27120, 'route': 'ZMR UN976 ARDID ERPES 4000N/02000W 4000N/03000W 4000N/04000W 4000N/05000W 4100N/06000W DOVEY N20B SAILE PLYMM PARCH3', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 473, 'distance_filed': 3782, 'filed_departure_time': {'epoch': 1559550600, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:30AM', 'date': '06/03/2019', 'localtime': 1559557800}, 'estimated_departure_time': {'epoch': 1559551634, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:47AM', 'date': '06/03/2019', 'localtime': 1559558834}, 'actual_departure_time': {'epoch': 1559551634, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:47AM', 'date': '06/03/2019', 'localtime': 1559558834}, 'departure_delay': -120, 'filed_arrival_time': {'epoch': 1559577720, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:02PM', 'date': '06/03/2019', 'localtime': 1559563320}, 'estimated_arrival_time': {'epoch': 1559578452, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:14PM', 'date': '06/03/2019', 'localtime': 1559564052}, 'actual_arrival_time': {'epoch': 1559578452, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:14PM', 'date': '06/03/2019', 'localtime': 1559564052}, 'arrival_delay': -780, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B764', 'full_aircrafttype': 'B764', 'adhoc': False}]}}"
        self.stubbed_find_flights_using_origin_destination_response = {'FindFlightResult': {'num_flights': 15, 'flights': [{'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560346519-airline-0332', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N359DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10320, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560526800, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:40AM', 'date': '06/14/2019', 'localtime': 1560512400}, 'estimated_departure_time': {'epoch': 1560527520, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:52AM', 'date': '06/14/2019', 'localtime': 1560513120}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560537120, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:32PM', 'date': '06/14/2019', 'localtime': 1560522720}, 'estimated_arrival_time': {'epoch': 1560537899, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:44PM', 'date': '06/14/2019', 'localtime': 1560523499}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 779, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560338700-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560348180-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9780, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560520980, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:03AM', 'date': '06/14/2019', 'localtime': 1560506580}, 'estimated_departure_time': {'epoch': 1560522420, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:27AM', 'date': '06/14/2019', 'localtime': 1560508020}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560530760, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:46PM', 'date': '06/14/2019', 'localtime': 1560516360}, 'estimated_arrival_time': {'epoch': 1560532259, 'tz': 'EDT', 'dow': 'Friday', 'time': '01:10PM', 'date': '06/14/2019', 'localtime': 1560517859}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560333660-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560341100-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N349DX', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513900, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:05AM', 'date': '06/14/2019', 'localtime': 1560499500}, 'estimated_departure_time': {'epoch': 1560514500, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:15AM', 'date': '06/14/2019', 'localtime': 1560500100}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560523620, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:47AM', 'date': '06/14/2019', 'localtime': 1560509220}, 'estimated_arrival_time': {'epoch': 1560524220, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:57AM', 'date': '06/14/2019', 'localtime': 1560509820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560260106-airline-0483', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560340800-schedule-0003', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N970JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513600, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:00AM', 'date': '06/14/2019', 'localtime': 1560499200}, 'estimated_departure_time': {'epoch': 1560514800, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:20AM', 'date': '06/14/2019', 'localtime': 1560500400}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560523320, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:42AM', 'date': '06/14/2019', 'localtime': 1560508920}, 'estimated_arrival_time': {'epoch': 1560524550, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:02AM', 'date': '06/14/2019', 'localtime': 1560510150}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU2504-1560320760-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU601', 'faFlightID': 'JBU601-1560331800-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '601', 'tailnumber': 'N965JT', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560504600, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:30AM', 'date': '06/14/2019', 'localtime': 1560490200}, 'estimated_departure_time': {'epoch': 1560505200, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:40AM', 'date': '06/14/2019', 'localtime': 1560490800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560514140, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:09AM', 'date': '06/14/2019', 'localtime': 1560499740}, 'estimated_arrival_time': {'epoch': 1560514740, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:19AM', 'date': '06/14/2019', 'localtime': 1560500340}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU36-1560260103-airline-0369', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL667', 'faFlightID': 'DAL667-1560260106-airline-0188', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '667', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10500, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'estimated_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'estimated_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2456-1560260106-airline-0264', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1201', 'faFlightID': 'JBU1201-1560260107-airline-0090', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1201', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560465600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:40PM', 'date': '06/13/2019', 'localtime': 1560451200}, 'estimated_departure_time': {'epoch': 1560466320, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:52PM', 'date': '06/13/2019', 'localtime': 1560451920}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560475140, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:19PM', 'date': '06/13/2019', 'localtime': 1560460740}, 'estimated_arrival_time': {'epoch': 1560475866, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:31PM', 'date': '06/13/2019', 'localtime': 1560461466}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1528-1560260103-airline-0426', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1401', 'faFlightID': 'JBU1401-1560260107-airline-0256', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1401', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12660, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560457800, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:30PM', 'date': '06/13/2019', 'localtime': 1560443400}, 'estimated_departure_time': {'epoch': 1560457200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:20PM', 'date': '06/13/2019', 'localtime': 1560442800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560470460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01PM', 'date': '06/13/2019', 'localtime': 1560456060}, 'estimated_arrival_time': {'epoch': 1560469860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:51PM', 'date': '06/13/2019', 'localtime': 1560455460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1202-1560260107-airline-0182', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL1656', 'faFlightID': 'DAL1656-1560260106-airline-0608', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '1656', 'tailnumber': 'N304DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10920, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'estimated_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'estimated_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2938-1560265200-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU201', 'faFlightID': 'JBU201-1560260103-airline-0056', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '201', 'tailnumber': 'N804JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10140, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 SPIKY AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560444360, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:46PM', 'date': '06/13/2019', 'localtime': 1560429960}, 'estimated_departure_time': {'epoch': 1560443760, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:36PM', 'date': '06/13/2019', 'localtime': 1560429360}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560454500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:35PM', 'date': '06/13/2019', 'localtime': 1560440100}, 'estimated_arrival_time': {'epoch': 1560453900, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:25PM', 'date': '06/13/2019', 'localtime': 1560439500}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 780, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU154-1560258360-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560260106-airline-0115', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10440, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 472, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560440400, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:40AM', 'date': '06/13/2019', 'localtime': 1560426000}, 'estimated_departure_time': {'epoch': 1560440100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:35AM', 'date': '06/13/2019', 'localtime': 1560425700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560450840, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:34PM', 'date': '06/13/2019', 'localtime': 1560436440}, 'estimated_arrival_time': {'epoch': 1560450540, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:29PM', 'date': '06/13/2019', 'localtime': 1560436140}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 360, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560252300-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560261780-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N954JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560434580, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:03AM', 'date': '06/13/2019', 'localtime': 1560420180}, 'estimated_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'actual_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560444300, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:45PM', 'date': '06/13/2019', 'localtime': 1560429900}, 'estimated_arrival_time': {'epoch': 1560448080, 'tz': 'EDT', 'dow': 'Thursday', 'time': '01:48PM', 'date': '06/13/2019', 'localtime': 1560433680}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 420, 'status': 'En Route / Delayed', 'progress_percent': 21, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560247260-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU627', 'faFlightID': 'JBU627-1560254460-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '627', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12900, 'route': 'RBV J230 COPES J75 DHP ZQA RENAH Y397 SEKAR', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 2089, 'filed_departure_time': {'epoch': 1560427260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01AM', 'date': '06/13/2019', 'localtime': 1560412860}, 'estimated_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'actual_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'departure_delay': 6103, 'filed_arrival_time': {'epoch': 1560440160, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:36AM', 'date': '06/13/2019', 'localtime': 1560425760}, 'estimated_arrival_time': {'epoch': 1560444956, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:55PM', 'date': '06/13/2019', 'localtime': 1560430556}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 9360, 'status': 'En Route / Delayed', 'progress_percent': 60, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1760-1560173686-airline-0187', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560254400-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10020, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 452, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:00AM', 'date': '06/13/2019', 'localtime': 1560412800}, 'estimated_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'actual_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560437220, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:47AM', 'date': '06/13/2019', 'localtime': 1560422820}, 'estimated_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'actual_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'arrival_delay': -1080, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU162-1560173686-airline-0243', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560254700-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N376DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9360, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:05AM', 'date': '06/13/2019', 'localtime': 1560413100}, 'estimated_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'actual_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'departure_delay': 1840, 'filed_arrival_time': {'epoch': 1560436860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:41AM', 'date': '06/13/2019', 'localtime': 1560422460}, 'estimated_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'actual_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'arrival_delay': 2040, 'status': 'Arrived / Delayed', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560173691-airline-0611', 'adhoc': False}]}], 'next_offset': 15}}, {'num_flights': 15, 'flights': [{'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560346519-airline-0332', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N359DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10320, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560526800, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:40AM', 'date': '06/14/2019', 'localtime': 1560512400}, 'estimated_departure_time': {'epoch': 1560527520, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:52AM', 'date': '06/14/2019', 'localtime': 1560513120}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560537120, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:32PM', 'date': '06/14/2019', 'localtime': 1560522720}, 'estimated_arrival_time': {'epoch': 1560537899, 'tz': 'EDT', 'dow': 'Friday', 'time': '02:44PM', 'date': '06/14/2019', 'localtime': 1560523499}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 779, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560338700-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560348180-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9780, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560520980, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:03AM', 'date': '06/14/2019', 'localtime': 1560506580}, 'estimated_departure_time': {'epoch': 1560522420, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:27AM', 'date': '06/14/2019', 'localtime': 1560508020}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560530760, 'tz': 'EDT', 'dow': 'Friday', 'time': '12:46PM', 'date': '06/14/2019', 'localtime': 1560516360}, 'estimated_arrival_time': {'epoch': 1560532259, 'tz': 'EDT', 'dow': 'Friday', 'time': '01:10PM', 'date': '06/14/2019', 'localtime': 1560517859}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560333660-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560341100-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N349DX', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513900, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:05AM', 'date': '06/14/2019', 'localtime': 1560499500}, 'estimated_departure_time': {'epoch': 1560514500, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:15AM', 'date': '06/14/2019', 'localtime': 1560500100}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560523620, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:47AM', 'date': '06/14/2019', 'localtime': 1560509220}, 'estimated_arrival_time': {'epoch': 1560524220, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:57AM', 'date': '06/14/2019', 'localtime': 1560509820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560260106-airline-0483', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560340800-schedule-0003', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N970JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560513600, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:00AM', 'date': '06/14/2019', 'localtime': 1560499200}, 'estimated_departure_time': {'epoch': 1560514800, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:20AM', 'date': '06/14/2019', 'localtime': 1560500400}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560523320, 'tz': 'EDT', 'dow': 'Friday', 'time': '10:42AM', 'date': '06/14/2019', 'localtime': 1560508920}, 'estimated_arrival_time': {'epoch': 1560524550, 'tz': 'EDT', 'dow': 'Friday', 'time': '11:02AM', 'date': '06/14/2019', 'localtime': 1560510150}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU2504-1560320760-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU601', 'faFlightID': 'JBU601-1560331800-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '601', 'tailnumber': 'N965JT', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 457, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560504600, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:30AM', 'date': '06/14/2019', 'localtime': 1560490200}, 'estimated_departure_time': {'epoch': 1560505200, 'tz': 'EDT', 'dow': 'Friday', 'time': '05:40AM', 'date': '06/14/2019', 'localtime': 1560490800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560514140, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:09AM', 'date': '06/14/2019', 'localtime': 1560499740}, 'estimated_arrival_time': {'epoch': 1560514740, 'tz': 'EDT', 'dow': 'Friday', 'time': '08:19AM', 'date': '06/14/2019', 'localtime': 1560500340}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU36-1560260103-airline-0369', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL667', 'faFlightID': 'DAL667-1560260106-airline-0188', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '667', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10500, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'estimated_departure_time': {'epoch': 1560470100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:55PM', 'date': '06/13/2019', 'localtime': 1560455700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'estimated_arrival_time': {'epoch': 1560480600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:50PM', 'date': '06/13/2019', 'localtime': 1560466200}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2456-1560260106-airline-0264', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1201', 'faFlightID': 'JBU1201-1560260107-airline-0090', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1201', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9540, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560465600, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:40PM', 'date': '06/13/2019', 'localtime': 1560451200}, 'estimated_departure_time': {'epoch': 1560466320, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:52PM', 'date': '06/13/2019', 'localtime': 1560451920}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560475140, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:19PM', 'date': '06/13/2019', 'localtime': 1560460740}, 'estimated_arrival_time': {'epoch': 1560475866, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:31PM', 'date': '06/13/2019', 'localtime': 1560461466}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1528-1560260103-airline-0426', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1401', 'faFlightID': 'JBU1401-1560260107-airline-0256', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1401', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12660, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560457800, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:30PM', 'date': '06/13/2019', 'localtime': 1560443400}, 'estimated_departure_time': {'epoch': 1560457200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '04:20PM', 'date': '06/13/2019', 'localtime': 1560442800}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560470460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01PM', 'date': '06/13/2019', 'localtime': 1560456060}, 'estimated_arrival_time': {'epoch': 1560469860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '07:51PM', 'date': '06/13/2019', 'localtime': 1560455460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1202-1560260107-airline-0182', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL1656', 'faFlightID': 'DAL1656-1560260106-airline-0608', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '1656', 'tailnumber': 'N304DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10920, 'route': 'WAVEY EMJAY J174 ORF J121 CHS CAKET Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'estimated_departure_time': {'epoch': 1560452940, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:09PM', 'date': '06/13/2019', 'localtime': 1560438540}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'estimated_arrival_time': {'epoch': 1560463860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '06:11PM', 'date': '06/13/2019', 'localtime': 1560449460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2938-1560265200-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU201', 'faFlightID': 'JBU201-1560260103-airline-0056', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '201', 'tailnumber': 'N804JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10140, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 SPIKY AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560444360, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:46PM', 'date': '06/13/2019', 'localtime': 1560429960}, 'estimated_departure_time': {'epoch': 1560443760, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:36PM', 'date': '06/13/2019', 'localtime': 1560429360}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560454500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:35PM', 'date': '06/13/2019', 'localtime': 1560440100}, 'estimated_arrival_time': {'epoch': 1560453900, 'tz': 'EDT', 'dow': 'Thursday', 'time': '03:25PM', 'date': '06/13/2019', 'localtime': 1560439500}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 780, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU154-1560258360-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2456', 'faFlightID': 'DAL2456-1560260106-airline-0115', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2456', 'tailnumber': 'N313DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10440, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 472, 'distance_filed': 1072, 'filed_departure_time': {'epoch': 1560440400, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:40AM', 'date': '06/13/2019', 'localtime': 1560426000}, 'estimated_departure_time': {'epoch': 1560440100, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:35AM', 'date': '06/13/2019', 'localtime': 1560425700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560450840, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:34PM', 'date': '06/13/2019', 'localtime': 1560436440}, 'estimated_arrival_time': {'epoch': 1560450540, 'tz': 'EDT', 'dow': 'Thursday', 'time': '02:29PM', 'date': '06/13/2019', 'localtime': 1560436140}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 360, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2732-1560252300-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU2901', 'faFlightID': 'JBU2901-1560261780-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2901', 'tailnumber': 'N954JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9720, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 465, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560434580, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:03AM', 'date': '06/13/2019', 'localtime': 1560420180}, 'estimated_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'actual_departure_time': {'epoch': 1560438495, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:08AM', 'date': '06/13/2019', 'localtime': 1560424095}, 'departure_delay': 720, 'filed_arrival_time': {'epoch': 1560444300, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:45PM', 'date': '06/13/2019', 'localtime': 1560429900}, 'estimated_arrival_time': {'epoch': 1560448080, 'tz': 'EDT', 'dow': 'Thursday', 'time': '01:48PM', 'date': '06/13/2019', 'localtime': 1560433680}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 420, 'status': 'En Route / Delayed', 'progress_percent': 21, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1502-1560247260-schedule-0000', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU627', 'faFlightID': 'JBU627-1560254460-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '627', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12900, 'route': 'RBV J230 COPES J75 DHP ZQA RENAH Y397 SEKAR', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 2089, 'filed_departure_time': {'epoch': 1560427260, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:01AM', 'date': '06/13/2019', 'localtime': 1560412860}, 'estimated_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'actual_departure_time': {'epoch': 1560433963, 'tz': 'EDT', 'dow': 'Thursday', 'time': '09:52AM', 'date': '06/13/2019', 'localtime': 1560419563}, 'departure_delay': 6103, 'filed_arrival_time': {'epoch': 1560440160, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:36AM', 'date': '06/13/2019', 'localtime': 1560425760}, 'estimated_arrival_time': {'epoch': 1560444956, 'tz': 'EDT', 'dow': 'Thursday', 'time': '12:55PM', 'date': '06/13/2019', 'localtime': 1560430556}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 9360, 'status': 'En Route / Delayed', 'progress_percent': 60, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1760-1560173686-airline-0187', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'JBU1701', 'faFlightID': 'JBU1701-1560254400-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1701', 'tailnumber': 'N999JQ', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 10020, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 452, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427200, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:00AM', 'date': '06/13/2019', 'localtime': 1560412800}, 'estimated_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'actual_departure_time': {'epoch': 1560428118, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:15AM', 'date': '06/13/2019', 'localtime': 1560413718}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560437220, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:47AM', 'date': '06/13/2019', 'localtime': 1560422820}, 'estimated_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'actual_arrival_time': {'epoch': 1560437460, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:51AM', 'date': '06/13/2019', 'localtime': 1560423060}, 'arrival_delay': -1080, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU162-1560173686-airline-0243', 'adhoc': False}]}, {'num_segments': 1, 'segments': [{'ident': 'DAL2324', 'faFlightID': 'DAL2324-1560254700-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2324', 'tailnumber': 'N376DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 9360, 'route': 'WAVEY EMJAY J174 SWL CEBEE WETRO ILM AR21 CRANS FISEL7', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 1190, 'filed_departure_time': {'epoch': 1560427500, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:05AM', 'date': '06/13/2019', 'localtime': 1560413100}, 'estimated_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'actual_departure_time': {'epoch': 1560429340, 'tz': 'EDT', 'dow': 'Thursday', 'time': '08:35AM', 'date': '06/13/2019', 'localtime': 1560414940}, 'departure_delay': 1840, 'filed_arrival_time': {'epoch': 1560436860, 'tz': 'EDT', 'dow': 'Thursday', 'time': '10:41AM', 'date': '06/13/2019', 'localtime': 1560422460}, 'estimated_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'actual_arrival_time': {'epoch': 1560438720, 'tz': 'EDT', 'dow': 'Thursday', 'time': '11:12AM', 'date': '06/13/2019', 'localtime': 1560424320}, 'arrival_delay': 2040, 'status': 'Arrived / Delayed', 'progress_percent': 100, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'DAL2279-1560173691-airline-0611', 'adhoc': False}]}], 'next_offset': 15}
        self.stubbed_find_flight_cancellation_statistics_response = {'FlightCancellationStatisticsResult': {'total_cancellations_worldwide': 1117, 'total_cancellations_national': 245, 'total_delays_worldwide': 23022, 'next_offset': -1, 'type_matching': 'airline', 'matching': [{'ident': 'AAL', 'description': 'American Airlines', 'cancellations': 63, 'delays': 834, 'total': 3570}]}}
        self.stubbed_find_airline_info_response = {'AirlineInfoResult': {'name': 'American Airlines Inc.', 'shortname': 'American Airlines', 'callsign': 'American', 'location': '', 'country': 'United States', 'phone': '+1-800-433-7300', 'url': 'http://www.aa.com/', 'wiki_url': 'https://en.wikipedia.org/wiki/American_Airlines', 'airbourne': 465, 'flights_last_24_hours': 3347}}
        self.stubbed_find_airport_boards_response = {'AirportBoardsResult': {'airport': 'KJFK', 'airport_info': {'airport_code': 'KJFK', 'name': 'John F Kennedy Intl', 'elevation': 12, 'city': 'New York', 'state': 'NY', 'longitude': -73.778695, 'latitude': 40.6399257, 'timezone': ':America/New_York', 'country_code': 'US', 'wiki_url': 'http://en.wikipedia.org/wiki/John_F_Kennedy_International', 'alternate_ident': 'JFK'}, 'arrivals': {'num_flights': 15, 'next_offset': 15, 'flights': [{'ident': 'JBU1592', 'faFlightID': 'JBU1592-1560611880-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1592', 'tailnumber': 'N368JB', 'type': 'Form_Airline', 'codeshares': 'QTR4004,RAM9652', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KACK', 'city': 'Nantucket, MA', 'alternate_ident': '', 'airport_name': 'Nantucket Memorial'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 3960, 'route': 'MVY SEY PARCH3', 'filed_altitude': 220, 'display_filed_altitude': '22,000 feet', 'filed_airspeed_kts': 411, 'distance_filed': 210, 'filed_departure_time': {'epoch': 1560784680, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:18AM', 'date': '06/17/2019', 'localtime': 1560770280}, 'estimated_departure_time': {'epoch': 1560788640, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:24PM', 'date': '06/17/2019', 'localtime': 1560774240}, 'actual_departure_time': {'epoch': 1560788680, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:24PM', 'date': '06/17/2019', 'localtime': 1560774280}, 'departure_delay': 3360, 'filed_arrival_time': {'epoch': 1560788640, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:24PM', 'date': '06/17/2019', 'localtime': 1560774240}, 'estimated_arrival_time': {'epoch': 1560791040, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:04PM', 'date': '06/17/2019', 'localtime': 1560776640}, 'actual_arrival_time': {'epoch': 1560791040, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:04PM', 'date': '06/17/2019', 'localtime': 1560776640}, 'arrival_delay': 2700, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'E190', 'full_aircrafttype': 'E190', 'inbound_faFlightID': 'JBU1491-1560592740-schedule-0000', 'adhoc': False}, {'ident': 'JBU1630', 'faFlightID': 'JBU1630-1560609900-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1630', 'tailnumber': 'N593JB', 'type': 'Form_Airline', 'codeshares': 'UAE6814,TAP4372,SIA1500,SIA1500,QTR4132,ELY8717,EIN5331,THY8524', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KRSW', 'city': 'Fort Myers, FL', 'alternate_ident': '', 'airport_name': 'Southwest Florida Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 8400, 'route': 'CSHEL6 LAL JINOS ETORE FEMON Q87 JROSS BARTL J121 SIE CAMRN4', 'filed_altitude': 350, 'display_filed_altitude': '35,000 feet', 'filed_airspeed_kts': 458, 'distance_filed': 1129, 'filed_departure_time': {'epoch': 1560782700, 'tz': 'EDT', 'dow': 'Monday', 'time': '10:45AM', 'date': '06/17/2019', 'localtime': 1560768300}, 'estimated_departure_time': {'epoch': 1560782968, 'tz': 'EDT', 'dow': 'Monday', 'time': '10:49AM', 'date': '06/17/2019', 'localtime': 1560768568}, 'actual_departure_time': {'epoch': 1560782968, 'tz': 'EDT', 'dow': 'Monday', 'time': '10:49AM', 'date': '06/17/2019', 'localtime': 1560768568}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560791100, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:05PM', 'date': '06/17/2019', 'localtime': 1560776700}, 'estimated_arrival_time': {'epoch': 1560790920, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:02PM', 'date': '06/17/2019', 'localtime': 1560776520}, 'actual_arrival_time': {'epoch': 1560790920, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:02PM', 'date': '06/17/2019', 'localtime': 1560776520}, 'arrival_delay': -1080, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU329-1560596400-schedule-0003', 'adhoc': False}, {'ident': 'JBU678', 'faFlightID': 'JBU678-1560609660-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '678', 'tailnumber': 'N520JB', 'type': 'Form_Airline', 'codeshares': 'UAE6742,THY8982,TAP4300,SIA1464,ELY8656,QTR4092,RAM9593', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJAX', 'city': 'Jacksonville, FL', 'alternate_ident': '', 'airport_name': 'Jacksonville Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 8460, 'route': 'CROSB2 WISPR JROSS BARTL J121 SIE CAMRN4', 'filed_altitude': 350, 'display_filed_altitude': '35,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 850, 'filed_departure_time': {'epoch': 1560782460, 'tz': 'EDT', 'dow': 'Monday', 'time': '10:41AM', 'date': '06/17/2019', 'localtime': 1560768060}, 'estimated_departure_time': {'epoch': 1560784390, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:13AM', 'date': '06/17/2019', 'localtime': 1560769990}, 'actual_departure_time': {'epoch': 1560784390, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:13AM', 'date': '06/17/2019', 'localtime': 1560769990}, 'departure_delay': 1080, 'filed_arrival_time': {'epoch': 1560790920, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:02PM', 'date': '06/17/2019', 'localtime': 1560776520}, 'estimated_arrival_time': {'epoch': 1560790740, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:59PM', 'date': '06/17/2019', 'localtime': 1560776340}, 'actual_arrival_time': {'epoch': 1560790740, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:59PM', 'date': '06/17/2019', 'localtime': 1560776340}, 'arrival_delay': -180, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU677-1560598260-schedule-0000', 'adhoc': False}, {'ident': 'DAL2', 'faFlightID': 'DAL2-1560591000-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2', 'tailnumber': 'N851NW', 'type': 'Form_Airline', 'codeshares': 'KLM6102,AFR3666,VIR4031', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'EGLL', 'city': 'London, England', 'alternate_ident': 'LHR', 'airport_name': 'London Heathrow'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 24660, 'route': 'KODIK N538C TAFFY PQI J55 ENE PARCH3', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 469, 'distance_filed': 3540, 'filed_departure_time': {'epoch': 1560763800, 'tz': 'BST', 'dow': 'Monday', 'time': '10:30AM', 'date': '06/17/2019', 'localtime': 1560767400}, 'estimated_departure_time': {'epoch': 1560765381, 'tz': 'BST', 'dow': 'Monday', 'time': '10:56AM', 'date': '06/17/2019', 'localtime': 1560768981}, 'actual_departure_time': {'epoch': 1560765381, 'tz': 'BST', 'dow': 'Monday', 'time': '10:56AM', 'date': '06/17/2019', 'localtime': 1560768981}, 'departure_delay': 981, 'filed_arrival_time': {'epoch': 1560788460, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:21PM', 'date': '06/17/2019', 'localtime': 1560774060}, 'estimated_arrival_time': {'epoch': 1560790680, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:58PM', 'date': '06/17/2019', 'localtime': 1560776280}, 'actual_arrival_time': {'epoch': 1560790680, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:58PM', 'date': '06/17/2019', 'localtime': 1560776280}, 'arrival_delay': -1200, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'A332', 'full_aircrafttype': 'A332', 'inbound_faFlightID': 'DAL16-1560519299-airline-0247', 'adhoc': False}, {'ident': 'EDV5517', 'faFlightID': 'EDV5517-1560605736-airline-0022', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5517', 'tailnumber': 'N8908D', 'type': 'Form_Airline', 'codeshares': 'AFR8875,AFR8875,WJA6434,KLM5585,KAL7379,GLO8340,DAL5517,AZA5851', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'CYUL', 'city': 'Montreal, Quebec', 'alternate_ident': '', 'airport_name': 'Montreal-Trudeau'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 3000, 'route': 'FAWNS BUGSY J570 ALB IGN IGN1', 'filed_altitude': 260, 'display_filed_altitude': '26,000 feet', 'filed_airspeed_kts': 451, 'distance_filed': 334, 'filed_departure_time': {'epoch': 1560787020, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:57AM', 'date': '06/17/2019', 'localtime': 1560772620}, 'estimated_departure_time': {'epoch': 1560787140, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:59AM', 'date': '06/17/2019', 'localtime': 1560772740}, 'actual_departure_time': {'epoch': 1560787080, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:58AM', 'date': '06/17/2019', 'localtime': 1560772680}, 'departure_delay': -420, 'filed_arrival_time': {'epoch': 1560790020, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:47PM', 'date': '06/17/2019', 'localtime': 1560775620}, 'estimated_arrival_time': {'epoch': 1560790620, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:57PM', 'date': '06/17/2019', 'localtime': 1560776220}, 'actual_arrival_time': {'epoch': 1560790620, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:57PM', 'date': '06/17/2019', 'localtime': 1560776220}, 'arrival_delay': -1560, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'CRJ2', 'full_aircrafttype': 'CRJ2', 'inbound_faFlightID': 'EDV5152-1560606000-schedule-0000', 'adhoc': False}, {'ident': 'EDV5173', 'faFlightID': 'EDV5173-1560605736-airline-0050', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5173', 'tailnumber': 'N8896A', 'type': 'Form_Airline', 'codeshares': 'KLM7991,KLM7991,DAL5173,AZA3418,AZA3418,AMX3401,AFR2535,AFR2535,WJA7044', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KRIC', 'city': 'Richmond, VA', 'alternate_ident': '', 'airport_name': 'Richmond Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 2520, 'route': 'LUCYL5 LUCYL PXT GARED PANZE V44 CAMRN', 'filed_altitude': 170, 'display_filed_altitude': '17,000 feet', 'filed_airspeed_kts': 391, 'distance_filed': 301, 'filed_departure_time': {'epoch': 1560787020, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:57AM', 'date': '06/17/2019', 'localtime': 1560772620}, 'estimated_departure_time': {'epoch': 1560787845, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:10PM', 'date': '06/17/2019', 'localtime': 1560773445}, 'actual_departure_time': {'epoch': 1560787845, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:10PM', 'date': '06/17/2019', 'localtime': 1560773445}, 'departure_delay': -600, 'filed_arrival_time': {'epoch': 1560789540, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:39PM', 'date': '06/17/2019', 'localtime': 1560775140}, 'estimated_arrival_time': {'epoch': 1560790560, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:56PM', 'date': '06/17/2019', 'localtime': 1560776160}, 'actual_arrival_time': {'epoch': 1560790560, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:56PM', 'date': '06/17/2019', 'localtime': 1560776160}, 'arrival_delay': -660, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'CRJ2', 'full_aircrafttype': 'CRJ2', 'inbound_faFlightID': 'EDV5173-1560605700-schedule-0000', 'adhoc': False}, {'ident': 'DAL107', 'faFlightID': 'DAL107-1560587700-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '107', 'tailnumber': 'N185DN', 'type': 'Form_Airline', 'codeshares': 'HVN3063,KLM6107,AFR3660,CSA3016', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'EDDF', 'city': 'Frankfurt am Main', 'alternate_ident': 'FRA', 'airport_name': "Frankfurt Int'l"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 28380, 'route': 'ENE PARCH3', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 450, 'distance_filed': 3882, 'filed_departure_time': {'epoch': 1560760500, 'tz': 'CEST', 'dow': 'Monday', 'time': '10:35AM', 'date': '06/17/2019', 'localtime': 1560767700}, 'estimated_departure_time': {'epoch': 1560762124, 'tz': 'CEST', 'dow': 'Monday', 'time': '11:02AM', 'date': '06/17/2019', 'localtime': 1560769324}, 'actual_departure_time': {'epoch': 1560762124, 'tz': 'CEST', 'dow': 'Monday', 'time': '11:02AM', 'date': '06/17/2019', 'localtime': 1560769324}, 'departure_delay': 120, 'filed_arrival_time': {'epoch': 1560788880, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:28PM', 'date': '06/17/2019', 'localtime': 1560774480}, 'estimated_arrival_time': {'epoch': 1560790520, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:55PM', 'date': '06/17/2019', 'localtime': 1560776120}, 'actual_arrival_time': {'epoch': 1560790520, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:55PM', 'date': '06/17/2019', 'localtime': 1560776120}, 'arrival_delay': -1320, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'B763', 'full_aircrafttype': 'B763', 'inbound_faFlightID': 'DAL86-1560519299-airline-0214', 'adhoc': False}, {'ident': 'DAL2068', 'faFlightID': 'DAL2068-1560603600-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2068', 'tailnumber': 'N359NW', 'type': 'Form_Airline', 'codeshares': 'AMX3262,VIR4640,KLM6277,AZA5978,AFR8845,AFL3431', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KSAT', 'city': 'San Antonio, TX', 'alternate_ident': '', 'airport_name': 'San Antonio Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 12420, 'route': 'CHURN WEMAR BLUMS IAH J2 LCH MEI ATL FIGEY Q64 TYI J209 ORF J121 SIE CAMRN4', 'filed_altitude': 350, 'display_filed_altitude': '35,000 feet', 'filed_airspeed_kts': 461, 'distance_filed': 1717, 'filed_departure_time': {'epoch': 1560776400, 'tz': 'CDT', 'dow': 'Monday', 'time': '08:00AM', 'date': '06/17/2019', 'localtime': 1560758400}, 'estimated_departure_time': {'epoch': 1560778588, 'tz': 'CDT', 'dow': 'Monday', 'time': '08:36AM', 'date': '06/17/2019', 'localtime': 1560760588}, 'actual_departure_time': {'epoch': 1560778588, 'tz': 'CDT', 'dow': 'Monday', 'time': '08:36AM', 'date': '06/17/2019', 'localtime': 1560760588}, 'departure_delay': 600, 'filed_arrival_time': {'epoch': 1560788820, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:27PM', 'date': '06/17/2019', 'localtime': 1560774420}, 'estimated_arrival_time': {'epoch': 1560790440, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:54PM', 'date': '06/17/2019', 'localtime': 1560776040}, 'actual_arrival_time': {'epoch': 1560790440, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:54PM', 'date': '06/17/2019', 'localtime': 1560776040}, 'arrival_delay': 60, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'DAL706-1560519300-airline-0092', 'adhoc': False}, {'ident': 'JBU117', 'faFlightID': 'JBU117-1560605713-airline-0061', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '117', 'tailnumber': 'N298JB', 'type': 'Form_Airline', 'codeshares': 'SIA1453,SIA1451,UAE6702,TAP4313,RAM9509,QTR3962,HAL2079,ELY8608,EIN5009', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KBOS', 'city': 'Boston, MA', 'alternate_ident': '', 'airport_name': 'Boston Logan Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 3180, 'route': 'SSOXS5 SSOXS BUZRD SEY PARCH3', 'filed_altitude': 220, 'display_filed_altitude': '22,000 feet', 'filed_airspeed_kts': 408, 'distance_filed': 252, 'filed_departure_time': {'epoch': 1560787800, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:10PM', 'date': '06/17/2019', 'localtime': 1560773400}, 'estimated_departure_time': {'epoch': 1560787641, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:07PM', 'date': '06/17/2019', 'localtime': 1560773241}, 'actual_departure_time': {'epoch': 1560787641, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:07PM', 'date': '06/17/2019', 'localtime': 1560773241}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560790980, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:03PM', 'date': '06/17/2019', 'localtime': 1560776580}, 'estimated_arrival_time': {'epoch': 1560790380, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:53PM', 'date': '06/17/2019', 'localtime': 1560775980}, 'actual_arrival_time': {'epoch': 1560790380, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:53PM', 'date': '06/17/2019', 'localtime': 1560775980}, 'arrival_delay': -1020, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'E190', 'full_aircrafttype': 'E190', 'inbound_faFlightID': 'JBU2280-1560604080-schedule-0000', 'adhoc': False}, {'ident': 'DAL843', 'faFlightID': 'DAL843-1560605713-airline-0143', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '843', 'tailnumber': 'N379DA', 'type': 'Form_Airline', 'codeshares': 'KLM6839,VIR4868,VIR4868,AZA3106,AZA3106,KLM7491,WJA8169,WJA6638', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KATL', 'city': 'Atlanta, GA', 'alternate_ident': '', 'airport_name': 'Hartsfield-Jackson Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 6000, 'route': 'PHIIL2 GRD Q64 TYI J209 SAWED J121 SIE CAMRN4', 'filed_altitude': 350, 'display_filed_altitude': '35,000 feet', 'filed_airspeed_kts': 469, 'distance_filed': 822, 'filed_departure_time': {'epoch': 1560783300, 'tz': 'EDT', 'dow': 'Monday', 'time': '10:55AM', 'date': '06/17/2019', 'localtime': 1560768900}, 'estimated_departure_time': {'epoch': 1560784149, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:09AM', 'date': '06/17/2019', 'localtime': 1560769749}, 'actual_departure_time': {'epoch': 1560784149, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:09AM', 'date': '06/17/2019', 'localtime': 1560769749}, 'departure_delay': 540, 'filed_arrival_time': {'epoch': 1560789300, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:35PM', 'date': '06/17/2019', 'localtime': 1560774900}, 'estimated_arrival_time': {'epoch': 1560790320, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:52PM', 'date': '06/17/2019', 'localtime': 1560775920}, 'actual_arrival_time': {'epoch': 1560790320, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:52PM', 'date': '06/17/2019', 'localtime': 1560775920}, 'arrival_delay': -600, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'B738', 'full_aircrafttype': 'B738', 'inbound_faFlightID': 'DAL1369-1560600000-schedule-0000', 'adhoc': False}, {'ident': 'JBU636', 'faFlightID': 'JBU636-1560605700-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '636', 'tailnumber': 'N809JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'MDST', 'city': 'Santiago', 'alternate_ident': 'STI', 'airport_name': "Cibao Int'l (Santiago Municipal)"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 12120, 'route': 'SGO T13 PTA LERED LAMER L453 PAEPR HOBOH SILLY STINK YAALE YETTI MOUGH DONAA OWENZ CAMRN', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 461, 'distance_filed': 1553, 'filed_departure_time': {'epoch': 1560778500, 'tz': 'AST', 'dow': 'Monday', 'time': '09:35AM', 'date': '06/17/2019', 'localtime': 1560764100}, 'estimated_departure_time': {'epoch': 1560778515, 'tz': 'AST', 'dow': 'Monday', 'time': '09:35AM', 'date': '06/17/2019', 'localtime': 1560764115}, 'actual_departure_time': {'epoch': 1560778515, 'tz': 'AST', 'dow': 'Monday', 'time': '09:35AM', 'date': '06/17/2019', 'localtime': 1560764115}, 'departure_delay': -720, 'filed_arrival_time': {'epoch': 1560790620, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:57PM', 'date': '06/17/2019', 'localtime': 1560776220}, 'estimated_arrival_time': {'epoch': 1560790260, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:51PM', 'date': '06/17/2019', 'localtime': 1560775860}, 'actual_arrival_time': {'epoch': 1560790260, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:51PM', 'date': '06/17/2019', 'localtime': 1560775860}, 'arrival_delay': -1320, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU837-1560589200-schedule-0004', 'adhoc': False}, {'ident': 'TCX2852', 'faFlightID': 'TCX2852-1560591300-schedule-0000', 'airline': 'TCX', 'airline_iata': 'MT', 'flightnumber': '2852', 'tailnumber': 'G-MLJL', 'type': 'Form_Airline', 'codeshares': 'CFG5852', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'EGCC', 'city': 'Manchester, England', 'alternate_ident': 'MAN', 'airport_name': 'Manchester'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 24900, 'route': 'IRLOK N576A TAFFY ENE PARCH3', 'filed_altitude': 380, 'display_filed_altitude': '38,000 feet', 'filed_airspeed_kts': 481, 'distance_filed': 3436, 'filed_departure_time': {'epoch': 1560764100, 'tz': 'BST', 'dow': 'Monday', 'time': '10:35AM', 'date': '06/17/2019', 'localtime': 1560767700}, 'estimated_departure_time': {'epoch': 1560765956, 'tz': 'BST', 'dow': 'Monday', 'time': '11:05AM', 'date': '06/17/2019', 'localtime': 1560769556}, 'actual_departure_time': {'epoch': 1560765956, 'tz': 'BST', 'dow': 'Monday', 'time': '11:05AM', 'date': '06/17/2019', 'localtime': 1560769556}, 'departure_delay': 900, 'filed_arrival_time': {'epoch': 1560789000, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:30PM', 'date': '06/17/2019', 'localtime': 1560774600}, 'estimated_arrival_time': {'epoch': 1560790169, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:49PM', 'date': '06/17/2019', 'localtime': 1560775769}, 'actual_arrival_time': {'epoch': 1560790169, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:49PM', 'date': '06/17/2019', 'localtime': 1560775769}, 'arrival_delay': 420, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'A332', 'full_aircrafttype': 'A332', 'adhoc': False}, {'ident': 'AUI231', 'faFlightID': 'AUI231-1560581100-schedule-0000', 'airline': 'AUI', 'airline_iata': 'PS', 'flightnumber': '231', 'tailnumber': 'UR-GOB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'UKBB', 'city': 'Boryspil (near Kiev)', 'alternate_ident': 'KBP', 'airport_name': "Boryspil Int'l"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 35400, 'route': 'ENE ROBER2', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 490, 'distance_filed': 4713, 'filed_departure_time': {'epoch': 1560753900, 'tz': 'EEST', 'dow': 'Monday', 'time': '09:45AM', 'date': '06/17/2019', 'localtime': 1560764700}, 'estimated_departure_time': {'epoch': 1560756912, 'tz': 'EEST', 'dow': 'Monday', 'time': '10:35AM', 'date': '06/17/2019', 'localtime': 1560767712}, 'actual_departure_time': {'epoch': 1560756912, 'tz': 'EEST', 'dow': 'Monday', 'time': '10:35AM', 'date': '06/17/2019', 'localtime': 1560767712}, 'departure_delay': 2460, 'filed_arrival_time': {'epoch': 1560789300, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:35PM', 'date': '06/17/2019', 'localtime': 1560774900}, 'estimated_arrival_time': {'epoch': 1560790090, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:48PM', 'date': '06/17/2019', 'localtime': 1560775690}, 'actual_arrival_time': {'epoch': 1560790090, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:48PM', 'date': '06/17/2019', 'localtime': 1560775690}, 'arrival_delay': -120, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'B772', 'full_aircrafttype': 'B772', 'adhoc': False}, {'ident': 'EDV5177', 'faFlightID': 'EDV5177-1560605736-airline-0086', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5177', 'tailnumber': 'N819AY', 'type': 'Form_Airline', 'codeshares': 'KLM7745,KLM7745,DAL5177,DAL5177,AZA5984,AZA5984,AFR2841,AFR2841,AMX3504', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KSYR', 'city': 'Syracuse, NY', 'alternate_ident': '', 'airport_name': 'Syracuse Hancock Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 4740, 'route': 'POMPY V273 HNK IGN IGN1', 'filed_altitude': 210, 'display_filed_altitude': '21,000 feet', 'filed_airspeed_kts': 415, 'distance_filed': 261, 'filed_departure_time': {'epoch': 1560786060, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:41AM', 'date': '06/17/2019', 'localtime': 1560771660}, 'estimated_departure_time': {'epoch': 1560787270, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:01PM', 'date': '06/17/2019', 'localtime': 1560772870}, 'actual_departure_time': {'epoch': 1560787270, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:01PM', 'date': '06/17/2019', 'localtime': 1560772870}, 'departure_delay': 420, 'filed_arrival_time': {'epoch': 1560790800, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:00PM', 'date': '06/17/2019', 'localtime': 1560776400}, 'estimated_arrival_time': {'epoch': 1560790048, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:47PM', 'date': '06/17/2019', 'localtime': 1560775648}, 'actual_arrival_time': {'epoch': 1560790048, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:47PM', 'date': '06/17/2019', 'localtime': 1560775648}, 'arrival_delay': 120, 'status': 'Arrived / Gate Arrival', 'progress_percent': 100, 'aircrafttype': 'CRJ2', 'full_aircrafttype': 'CRJ2', 'inbound_faFlightID': 'EDV5177-1560605760-schedule-0000', 'adhoc': False}, {'ident': 'CPA830', 'faFlightID': 'CPA830-1560561300-schedule-0000', 'airline': 'CPA', 'airline_iata': 'CX', 'flightnumber': '830', 'tailnumber': 'B-KQM', 'type': 'Form_Airline', 'codeshares': 'LAN5639,AAL8923,TAM4802', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'VHHH', 'city': 'Hong Kong', 'alternate_ident': 'HKG', 'airport_name': "Hong Kong Int'l"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 54000, 'route': 'TAMRU SEFIX TOU GEG DPR J34 BAE J70 LVZ LENDY6', 'filed_altitude': 310, 'display_filed_altitude': '31,000 feet', 'filed_airspeed_kts': 507, 'distance_filed': 8959, 'filed_departure_time': {'epoch': 1560734100, 'tz': 'HKT', 'dow': 'Monday', 'time': '09:15AM', 'date': '06/17/2019', 'localtime': 1560762900}, 'estimated_departure_time': {'epoch': 1560735212, 'tz': 'HKT', 'dow': 'Monday', 'time': '09:33AM', 'date': '06/17/2019', 'localtime': 1560764012}, 'actual_departure_time': {'epoch': 1560735212, 'tz': 'HKT', 'dow': 'Monday', 'time': '09:33AM', 'date': '06/17/2019', 'localtime': 1560764012}, 'departure_delay': -180, 'filed_arrival_time': {'epoch': 1560788100, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:15PM', 'date': '06/17/2019', 'localtime': 1560773700}, 'estimated_arrival_time': {'epoch': 1560789900, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:45PM', 'date': '06/17/2019', 'localtime': 1560775500}, 'actual_arrival_time': {'epoch': 1560789900, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:45PM', 'date': '06/17/2019', 'localtime': 1560775500}, 'arrival_delay': -1260, 'status': 'Landed / Taxiing', 'progress_percent': 100, 'aircrafttype': 'B77W', 'full_aircrafttype': 'B77W', 'adhoc': False}]}, 'departures': {'num_flights': 15, 'next_offset': 15, 'flights': [{'ident': 'EDV5004', 'faFlightID': 'EDV5004-1560605711-airline-0059', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5004', 'tailnumber': 'N695CA', 'type': 'Form_Airline', 'codeshares': 'DAL5004,DAL5004,AZA3207,AZA3207,AFR2896,AFR2896,WJA6830,WJA6830', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KBUF', 'city': 'Buffalo, NY', 'alternate_ident': '', 'airport_name': 'Buffalo Niagara Intl'}, 'filed_ete': 2940, 'route': 'NEION J223 CORDS J132 ULW BENEE', 'filed_altitude': 200, 'display_filed_altitude': '20,000 feet', 'filed_airspeed_kts': 410, 'distance_filed': 309, 'filed_departure_time': {'epoch': 1560790740, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:59PM', 'date': '06/17/2019', 'localtime': 1560776340}, 'estimated_departure_time': {'epoch': 1560791071, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:04PM', 'date': '06/17/2019', 'localtime': 1560776671}, 'actual_departure_time': {'epoch': 1560791071, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:04PM', 'date': '06/17/2019', 'localtime': 1560776671}, 'departure_delay': 120, 'filed_arrival_time': {'epoch': 1560793680, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:48PM', 'date': '06/17/2019', 'localtime': 1560779280}, 'estimated_arrival_time': {'epoch': 1560793980, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:53PM', 'date': '06/17/2019', 'localtime': 1560779580}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 120, 'status': 'En Route / On Time', 'progress_percent': 2, 'aircrafttype': 'CRJ9', 'full_aircrafttype': 'CRJ9', 'inbound_faFlightID': 'EDV5122-1560606600-schedule-0000', 'adhoc': False}, {'ident': 'DAL435', 'faFlightID': 'DAL435-1560615240-schedule-0001', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '435', 'tailnumber': 'N823DX', 'type': 'Form_Airline', 'codeshares': 'WJA7624,WJA7624,VIR4817,VIR4817,AZA3401,AZA3401,AMX4403,AMX4403,AFR3485,AFR3485', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KATL', 'city': 'Atlanta, GA', 'alternate_ident': '', 'airport_name': 'Hartsfield-Jackson Intl'}, 'filed_ete': 6300, 'route': 'RBV J230 BYRDD J48 FLASK OZZZI1', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 468, 'distance_filed': 821, 'filed_departure_time': {'epoch': 1560788040, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:14PM', 'date': '06/17/2019', 'localtime': 1560773640}, 'estimated_departure_time': {'epoch': 1560790931, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:02PM', 'date': '06/17/2019', 'localtime': 1560776531}, 'actual_departure_time': {'epoch': 1560790931, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:02PM', 'date': '06/17/2019', 'localtime': 1560776531}, 'departure_delay': -420, 'filed_arrival_time': {'epoch': 1560794340, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:59PM', 'date': '06/17/2019', 'localtime': 1560779940}, 'estimated_arrival_time': {'epoch': 1560797220, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:47PM', 'date': '06/17/2019', 'localtime': 1560782820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1800, 'status': 'En Route / Delayed', 'progress_percent': 3, 'aircrafttype': 'B752', 'full_aircrafttype': 'B752', 'inbound_faFlightID': 'DAL415-1560589200-schedule-0000', 'adhoc': False}, {'ident': 'JBU351', 'faFlightID': 'JBU351-1560605711-airline-0223', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '351', 'tailnumber': 'N655JB', 'type': 'Form_Airline', 'codeshares': 'UAE6833', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'MMUN', 'city': 'Cancun, Quintana Roo', 'alternate_ident': 'CUN', 'airport_name': "Cancun Int'l"}, 'filed_ete': 13440, 'route': 'RBV J230 COPES J75 TAY CIGAR M215 SNOMN M215 PISAD UM215 NUDIS ITLOM UM782 VOMAR VOMAR1A', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 461, 'distance_filed': 1694, 'filed_departure_time': {'epoch': 1560790440, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:54PM', 'date': '06/17/2019', 'localtime': 1560776040}, 'estimated_departure_time': {'epoch': 1560790737, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:58PM', 'date': '06/17/2019', 'localtime': 1560776337}, 'actual_departure_time': {'epoch': 1560790737, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:58PM', 'date': '06/17/2019', 'localtime': 1560776337}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560803880, 'tz': 'EST', 'dow': 'Monday', 'time': '03:38PM', 'date': '06/17/2019', 'localtime': 1560785880}, 'estimated_arrival_time': {'epoch': 1560803820, 'tz': 'EST', 'dow': 'Monday', 'time': '03:37PM', 'date': '06/17/2019', 'localtime': 1560785820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -660, 'status': 'En Route / On Time', 'progress_percent': 3, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU936-1560584280-schedule-0000', 'adhoc': False}, {'ident': 'JBU201', 'faFlightID': 'JBU201-1560605711-airline-0385', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '201', 'tailnumber': 'N827JB', 'type': 'Form_Airline', 'codeshares': 'UAE6729,SAA7390,HAL2036,AZU7423,QTR4087', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KFLL', 'city': 'Fort Lauderdale, FL', 'alternate_ident': '', 'airport_name': 'Fort Lauderdale Intl'}, 'filed_ete': 12300, 'route': 'RBV J230 COPES J75 GSO Q75 SLOJO Q83 JEVED Q97 KENLL OMN FISEL7', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 461, 'distance_filed': 1271, 'filed_departure_time': {'epoch': 1560789960, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:46PM', 'date': '06/17/2019', 'localtime': 1560775560}, 'estimated_departure_time': {'epoch': 1560790668, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:57PM', 'date': '06/17/2019', 'localtime': 1560776268}, 'actual_departure_time': {'epoch': 1560790668, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:57PM', 'date': '06/17/2019', 'localtime': 1560776268}, 'departure_delay': 180, 'filed_arrival_time': {'epoch': 1560802260, 'tz': 'EDT', 'dow': 'Monday', 'time': '04:11PM', 'date': '06/17/2019', 'localtime': 1560787860}, 'estimated_arrival_time': {'epoch': 1560800880, 'tz': 'EDT', 'dow': 'Monday', 'time': '03:48PM', 'date': '06/17/2019', 'localtime': 1560786480}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -420, 'status': 'En Route / On Time', 'progress_percent': 4, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU154-1560603960-schedule-0000', 'adhoc': False}, {'ident': 'JBU1318', 'faFlightID': 'JBU1318-1560605713-airline-0281', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1318', 'tailnumber': 'N206JB', 'type': 'Form_Airline', 'codeshares': 'UAE6705,SAA7354,QTR3921,HAL2000,EIN5018', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KBOS', 'city': 'Boston, MA', 'alternate_ident': '', 'airport_name': 'Boston Logan Intl'}, 'filed_ete': 3840, 'route': 'MERIT ROBUC3', 'filed_altitude': 170, 'display_filed_altitude': '17,000 feet', 'filed_airspeed_kts': 367, 'distance_filed': 205, 'filed_departure_time': {'epoch': 1560788640, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:24PM', 'date': '06/17/2019', 'localtime': 1560774240}, 'estimated_departure_time': {'epoch': 1560790330, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:52PM', 'date': '06/17/2019', 'localtime': 1560775930}, 'actual_departure_time': {'epoch': 1560790330, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:52PM', 'date': '06/17/2019', 'localtime': 1560775930}, 'departure_delay': 1380, 'filed_arrival_time': {'epoch': 1560792480, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:28PM', 'date': '06/17/2019', 'localtime': 1560778080}, 'estimated_arrival_time': {'epoch': 1560792240, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:24PM', 'date': '06/17/2019', 'localtime': 1560777840}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 240, 'status': 'En Route / On Time', 'progress_percent': 42, 'aircrafttype': 'E190', 'full_aircrafttype': 'E190', 'inbound_faFlightID': 'JBU886-1560607200-schedule-0001', 'adhoc': False}, {'ident': 'JBU586', 'faFlightID': 'JBU586-1560605711-airline-0180', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '586', 'tailnumber': 'N258JB', 'type': 'Form_Airline', 'codeshares': 'QTR4127,HAL2028,UAE6803', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KROC', 'city': 'Rochester, NY', 'alternate_ident': '', 'airport_name': 'Greater Rochester Intl'}, 'filed_ete': 3060, 'route': 'NEION J223 CORDS ULW V31 GIBBE', 'filed_altitude': 220, 'display_filed_altitude': '22,000 feet', 'filed_airspeed_kts': 408, 'distance_filed': 283, 'filed_departure_time': {'epoch': 1560786780, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:53AM', 'date': '06/17/2019', 'localtime': 1560772380}, 'estimated_departure_time': {'epoch': 1560790272, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:51PM', 'date': '06/17/2019', 'localtime': 1560775872}, 'actual_departure_time': {'epoch': 1560790272, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:51PM', 'date': '06/17/2019', 'localtime': 1560775872}, 'departure_delay': 3120, 'filed_arrival_time': {'epoch': 1560789840, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:44PM', 'date': '06/17/2019', 'localtime': 1560775440}, 'estimated_arrival_time': {'epoch': 1560793320, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:42PM', 'date': '06/17/2019', 'localtime': 1560778920}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 2280, 'status': 'En Route / Delayed', 'progress_percent': 28, 'aircrafttype': 'E190', 'full_aircrafttype': 'E190', 'inbound_faFlightID': 'JBU218-1560606540-schedule-0000', 'adhoc': False}, {'ident': 'JBU2879', 'faFlightID': 'JBU2879-1560605711-airline-0115', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '2879', 'tailnumber': 'N526JL', 'type': 'Form_Airline', 'codeshares': 'UAE6863', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'MKJS', 'city': 'Montego Bay', 'alternate_ident': 'MBJ', 'airport_name': "Sangster Int'l"}, 'filed_ete': 12900, 'route': 'WAVEY EMJAY J174 DIW AR23 PANAL AR3 CARPX Y307 ENAMO UR625 NEFTU R625 ULDAR TILUP LENAR5', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 467, 'distance_filed': 1615, 'filed_departure_time': {'epoch': 1560789780, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:43PM', 'date': '06/17/2019', 'localtime': 1560775380}, 'estimated_departure_time': {'epoch': 1560790140, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:49PM', 'date': '06/17/2019', 'localtime': 1560775740}, 'actual_departure_time': {'epoch': 1560790217, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:50PM', 'date': '06/17/2019', 'localtime': 1560775817}, 'departure_delay': -60, 'filed_arrival_time': {'epoch': 1560802680, 'tz': 'EST', 'dow': 'Monday', 'time': '03:18PM', 'date': '06/17/2019', 'localtime': 1560784680}, 'estimated_arrival_time': {'epoch': 1560802440, 'tz': 'EST', 'dow': 'Monday', 'time': '03:14PM', 'date': '06/17/2019', 'localtime': 1560784440}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1080, 'status': 'En Route / On Time', 'progress_percent': 7, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU842-1560605280-schedule-0000', 'adhoc': False}, {'ident': 'NRS7914', 'faFlightID': 'NRS7914-1560790081-adhoc-0', 'airline': 'NRS', 'airline_iata': 'DI', 'flightnumber': '7914', 'tailnumber': 'EC-NBP', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'EGKK', 'city': 'London, England', 'alternate_ident': 'LGW', 'airport_name': 'London Gatwick'}, 'filed_departure_time': {'epoch': 1560790081, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:48PM', 'date': '06/17/2019', 'localtime': 1560775681}, 'estimated_departure_time': {'epoch': 1560790081, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:48PM', 'date': '06/17/2019', 'localtime': 1560775681}, 'actual_departure_time': {'epoch': 1560790081, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:48PM', 'date': '06/17/2019', 'localtime': 1560775681}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 0}, 'estimated_arrival_time': {'epoch': 0}, 'actual_arrival_time': {'epoch': 0}, 'status': 'En Route', 'progress_percent': -1, 'adhoc': True}, {'ident': 'THY4', 'faFlightID': 'THY4-1560605732-airline-0431', 'airline': 'THY', 'airline_iata': 'TK', 'flightnumber': '4', 'tailnumber': 'TC-JOB', 'type': 'Form_Airline', 'codeshares': 'UZB7284,AVA6624', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'LTFM', 'city': 'Istanbul', 'alternate_ident': 'IST', 'airport_name': 'Istanbul Airport'}, 'filed_ete': 33900, 'route': 'BETTE ACK KANNI N139A PORTI 4700N/05000W 4800N/04000W 4900N/03000W 5000N/02000W SOMAX ATSUR GAPLI UL739 LIZAD LUMOG LARDU LABIG URELO GELTA BEGAR UN491 DEGES UN871 GAMSA GEDSO MAGAM VIBOP ETIDA T390 RILEX', 'filed_altitude': 290, 'display_filed_altitude': '29,000 feet', 'filed_airspeed_kts': 447, 'distance_filed': 4993, 'filed_departure_time': {'epoch': 1560789600, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:40PM', 'date': '06/17/2019', 'localtime': 1560775200}, 'estimated_departure_time': {'epoch': 1560789791, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:43PM', 'date': '06/17/2019', 'localtime': 1560775391}, 'actual_departure_time': {'epoch': 1560789791, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:43PM', 'date': '06/17/2019', 'localtime': 1560775391}, 'departure_delay': 191, 'filed_arrival_time': {'epoch': 1560823500, 'tz': '+03', 'dow': 'Tuesday', 'time': '05:05AM', 'date': '06/18/2019', 'localtime': 1560834300}, 'estimated_arrival_time': {'epoch': 1560823740, 'tz': '+03', 'dow': 'Tuesday', 'time': '05:09AM', 'date': '06/18/2019', 'localtime': 1560834540}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 240, 'status': 'En Route / On Time', 'progress_percent': 3, 'aircrafttype': 'A333', 'full_aircrafttype': 'A333', 'adhoc': False}, {'ident': 'AAL3', 'faFlightID': 'AAL3-1560605709-airline-0322', 'airline': 'AAL', 'airline_iata': 'AA', 'flightnumber': '3', 'tailnumber': 'N117AN', 'type': 'Form_Airline', 'codeshares': 'BAW4720,QFA3094,THT1103,TAM7814', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KLAX', 'city': 'Los Angeles, CA', 'alternate_ident': '', 'airport_name': 'Los Angeles Intl'}, 'filed_ete': 19740, 'route': 'RBV J230 AIR J80 VHP KK54E KK51A KD39Q JASSE Q90 DNERO ANJLL4', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 462, 'distance_filed': 2492, 'filed_departure_time': {'epoch': 1560789540, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:39PM', 'date': '06/17/2019', 'localtime': 1560775140}, 'estimated_departure_time': {'epoch': 1560789499, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:38PM', 'date': '06/17/2019', 'localtime': 1560775099}, 'actual_departure_time': {'epoch': 1560789499, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:38PM', 'date': '06/17/2019', 'localtime': 1560775099}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560809280, 'tz': 'PDT', 'dow': 'Monday', 'time': '03:08PM', 'date': '06/17/2019', 'localtime': 1560784080}, 'estimated_arrival_time': {'epoch': 1560808440, 'tz': 'PDT', 'dow': 'Monday', 'time': '02:54PM', 'date': '06/17/2019', 'localtime': 1560783240}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1320, 'status': 'En Route / On Time', 'progress_percent': 8, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'AAL2201-1560519291-airline-0030', 'adhoc': False}, {'ident': 'AIJ2995', 'faFlightID': 'AIJ2995-1560609000-schedule-0000', 'airline': 'AIJ', 'airline_iata': '4O', 'flightnumber': '2995', 'tailnumber': 'XA-ING', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'MMMX', 'city': 'Mexico City', 'alternate_ident': 'MEX', 'airport_name': "Lic. Benito Juarez Int'l"}, 'filed_ete': 10980, 'route': 'RBV J230 COPES J75 GVE J37 SJI TBD M345 AXEXO UM345 PAZ UJ55 DATUL DATUL4A', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 448, 'distance_filed': 2163, 'filed_departure_time': {'epoch': 1560781800, 'tz': 'EDT', 'dow': 'Monday', 'time': '10:30AM', 'date': '06/17/2019', 'localtime': 1560767400}, 'estimated_departure_time': {'epoch': 1560789411, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:36PM', 'date': '06/17/2019', 'localtime': 1560775011}, 'actual_departure_time': {'epoch': 1560789411, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:36PM', 'date': '06/17/2019', 'localtime': 1560775011}, 'departure_delay': 7611, 'filed_arrival_time': {'epoch': 1560792780, 'tz': 'CDT', 'dow': 'Monday', 'time': '12:33PM', 'date': '06/17/2019', 'localtime': 1560774780}, 'estimated_arrival_time': {'epoch': 1560805980, 'tz': 'CDT', 'dow': 'Monday', 'time': '04:13PM', 'date': '06/17/2019', 'localtime': 1560787980}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 13200, 'status': 'En Route / Delayed', 'progress_percent': 10, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'adhoc': False}, {'ident': 'EDV5302', 'faFlightID': 'EDV5302-1560605736-airline-0126', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5302', 'tailnumber': 'N331PQ', 'type': 'Form_Airline', 'codeshares': 'AZA5877,AFR2181,WJA7459,DAL5302', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KCLE', 'city': 'Cleveland, OH', 'alternate_ident': '', 'airport_name': 'Cleveland-Hopkins Intl'}, 'filed_ete': 4380, 'route': 'DEEZZ5 CANDR J60 PSB UPPRR TRYBE2', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 480, 'distance_filed': 425, 'filed_departure_time': {'epoch': 1560788700, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:25PM', 'date': '06/17/2019', 'localtime': 1560774300}, 'estimated_departure_time': {'epoch': 1560788997, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:29PM', 'date': '06/17/2019', 'localtime': 1560774597}, 'actual_departure_time': {'epoch': 1560788997, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:29PM', 'date': '06/17/2019', 'localtime': 1560774597}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560793080, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:38PM', 'date': '06/17/2019', 'localtime': 1560778680}, 'estimated_arrival_time': {'epoch': 1560793140, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:39PM', 'date': '06/17/2019', 'localtime': 1560778740}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1140, 'status': 'En Route / On Time', 'progress_percent': 51, 'aircrafttype': 'CRJ9', 'full_aircrafttype': 'CRJ9', 'inbound_faFlightID': 'EDV5164-1560607200-schedule-0000', 'adhoc': False}, {'ident': 'ENY3957', 'faFlightID': 'ENY3957-1560605709-airline-0441', 'airline': 'ENY', 'airline_iata': 'MQ', 'flightnumber': '3957', 'tailnumber': 'N812AE', 'type': 'Form_Airline', 'codeshares': 'QFA3269,AAL3957', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'CYYZ', 'city': 'Toronto, Ontario', 'alternate_ident': '', 'airport_name': "Toronto Pearson Int'l"}, 'filed_ete': 3900, 'route': 'GAYEL Q818 WOZEE LINNG9', 'filed_altitude': 220, 'display_filed_altitude': '22,000 feet', 'filed_airspeed_kts': 433, 'distance_filed': 421, 'filed_departure_time': {'epoch': 1560788100, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:15PM', 'date': '06/17/2019', 'localtime': 1560773700}, 'estimated_departure_time': {'epoch': 1560788901, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:28PM', 'date': '06/17/2019', 'localtime': 1560774501}, 'actual_departure_time': {'epoch': 1560788901, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:28PM', 'date': '06/17/2019', 'localtime': 1560774501}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560792000, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:20PM', 'date': '06/17/2019', 'localtime': 1560777600}, 'estimated_arrival_time': {'epoch': 1560792720, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:32PM', 'date': '06/17/2019', 'localtime': 1560778320}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -420, 'status': 'En Route / On Time', 'progress_percent': 58, 'aircrafttype': 'E135', 'full_aircrafttype': 'E135', 'inbound_faFlightID': 'ENY3811-1560600120-airline-0164', 'adhoc': False}, {'ident': 'EDV5120', 'faFlightID': 'EDV5120-1560605713-airline-0029', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5120', 'tailnumber': 'N8970D', 'type': 'Form_Airline', 'codeshares': 'DAL5120,AFR2610', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KBTV', 'city': 'Burlington, VT', 'alternate_ident': '', 'airport_name': 'Burlington Intl'}, 'filed_ete': 2340, 'route': 'GREKI JUDDS CAM', 'filed_altitude': 220, 'display_filed_altitude': '22,000 feet', 'filed_airspeed_kts': 422, 'distance_filed': 267, 'filed_departure_time': {'epoch': 1560788160, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:16PM', 'date': '06/17/2019', 'localtime': 1560773760}, 'estimated_departure_time': {'epoch': 1560788828, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:27PM', 'date': '06/17/2019', 'localtime': 1560774428}, 'actual_departure_time': {'epoch': 1560788828, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:27PM', 'date': '06/17/2019', 'localtime': 1560774428}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560790500, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:55PM', 'date': '06/17/2019', 'localtime': 1560776100}, 'estimated_arrival_time': {'epoch': 1560791340, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:09PM', 'date': '06/17/2019', 'localtime': 1560776940}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -540, 'status': 'En Route / On Time', 'progress_percent': 91, 'aircrafttype': 'CRJ2', 'full_aircrafttype': 'CRJ2', 'inbound_faFlightID': 'EDV3474-1560605711-airline-0046', 'adhoc': False}, {'ident': 'JBU789', 'faFlightID': 'JBU789-1560605711-airline-0142', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '789', 'tailnumber': 'N948JB', 'type': 'Form_Airline', 'codeshares': 'ELY8674,AZU7613,AZU7385,UAE6745,QTR3965,SAA7366,HAL2066', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KMCO', 'city': 'Orlando, FL', 'alternate_ident': '', 'airport_name': 'Orlando Intl'}, 'filed_ete': 10200, 'route': 'WAVEY EMJAY J174 ORF J121 CHS IGARY Q85 LPERD OMN CWRLD4', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 460, 'distance_filed': 1045, 'filed_departure_time': {'epoch': 1560787800, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:10PM', 'date': '06/17/2019', 'localtime': 1560773400}, 'estimated_departure_time': {'epoch': 1560788580, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:23PM', 'date': '06/17/2019', 'localtime': 1560774180}, 'actual_departure_time': {'epoch': 1560788580, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:23PM', 'date': '06/17/2019', 'localtime': 1560774180}, 'departure_delay': -120, 'filed_arrival_time': {'epoch': 1560798000, 'tz': 'EDT', 'dow': 'Monday', 'time': '03:00PM', 'date': '06/17/2019', 'localtime': 1560783600}, 'estimated_arrival_time': {'epoch': 1560796320, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:32PM', 'date': '06/17/2019', 'localtime': 1560781920}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 540, 'status': 'En Route / On Time', 'progress_percent': 32, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1810-1560592800-schedule-0000', 'adhoc': False}]}, 'enroute': {'num_flights': 15, 'next_offset': 15, 'flights': [{'ident': 'EDV5274', 'faFlightID': 'EDV5274-1560605736-airline-0066', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5274', 'tailnumber': 'N341PQ', 'type': 'Form_Airline', 'codeshares': 'DAL5274,WJA6883,WJA6883,KLM7231', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KRDU', 'city': 'Raleigh/Durham, NC', 'alternate_ident': '', 'airport_name': 'Raleigh-Durham Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 3540, 'route': 'HURIC3 TYI ORF J121 SIE CAMRN4', 'filed_altitude': 330, 'display_filed_altitude': '33,000 feet', 'filed_airspeed_kts': 474, 'distance_filed': 462, 'filed_departure_time': {'epoch': 1560784680, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:18AM', 'date': '06/17/2019', 'localtime': 1560770280}, 'estimated_departure_time': {'epoch': 1560787321, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:02PM', 'date': '06/17/2019', 'localtime': 1560772921}, 'actual_departure_time': {'epoch': 1560787260, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:01PM', 'date': '06/17/2019', 'localtime': 1560772860}, 'departure_delay': 2400, 'filed_arrival_time': {'epoch': 1560788220, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:17PM', 'date': '06/17/2019', 'localtime': 1560773820}, 'estimated_arrival_time': {'epoch': 1560791100, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:05PM', 'date': '06/17/2019', 'localtime': 1560776700}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 1200, 'status': 'En Route / Delayed', 'progress_percent': 99, 'aircrafttype': 'CRJ9', 'full_aircrafttype': 'CRJ9', 'inbound_faFlightID': 'EDV5266-1560601800-schedule-0003', 'adhoc': False}, {'ident': 'JBU906', 'faFlightID': 'JBU906-1560605711-airline-0044', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '906', 'tailnumber': 'N337JB', 'type': 'Form_Airline', 'codeshares': 'ELY8690,QTR3924,UAE6072,SIA1486,RAM9545,TAP4342', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KORD', 'city': 'Chicago, IL', 'alternate_ident': '', 'airport_name': "Chicago O'Hare Intl"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 7800, 'route': 'DUFEE ELX HAAKK DOXXY DXO JHW J70 LVZ LENDY6', 'filed_altitude': 370, 'display_filed_altitude': '37,000 feet', 'filed_airspeed_kts': 451, 'distance_filed': 739, 'filed_departure_time': {'epoch': 1560784740, 'tz': 'CDT', 'dow': 'Monday', 'time': '10:19AM', 'date': '06/17/2019', 'localtime': 1560766740}, 'estimated_departure_time': {'epoch': 1560786088, 'tz': 'CDT', 'dow': 'Monday', 'time': '10:41AM', 'date': '06/17/2019', 'localtime': 1560768088}, 'actual_departure_time': {'epoch': 1560786088, 'tz': 'CDT', 'dow': 'Monday', 'time': '10:41AM', 'date': '06/17/2019', 'localtime': 1560768088}, 'departure_delay': 480, 'filed_arrival_time': {'epoch': 1560792540, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:29PM', 'date': '06/17/2019', 'localtime': 1560778140}, 'estimated_arrival_time': {'epoch': 1560791160, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:06PM', 'date': '06/17/2019', 'localtime': 1560776760}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -120, 'status': 'En Route / On Time', 'progress_percent': 99, 'aircrafttype': 'E190', 'full_aircrafttype': 'E190', 'inbound_faFlightID': 'JBU1105-1560599220-schedule-0000', 'adhoc': False}, {'ident': 'JBU107', 'faFlightID': 'JBU107-1560615600-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '107', 'tailnumber': 'N348JB', 'type': 'Form_Airline', 'codeshares': 'UAE6760,THY8500,TAP4309,SIA1495,ELY8701', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KPWM', 'city': 'Portland, ME', 'alternate_ident': '', 'airport_name': 'Portland Intl Jetport'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 3060, 'route': 'NUBLE4 JJIMY PVD ROBER2', 'filed_altitude': 260, 'display_filed_altitude': '26,000 feet', 'filed_airspeed_kts': 413, 'distance_filed': 274, 'filed_departure_time': {'epoch': 1560788400, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:20PM', 'date': '06/17/2019', 'localtime': 1560774000}, 'estimated_departure_time': {'epoch': 1560788160, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:16PM', 'date': '06/17/2019', 'localtime': 1560773760}, 'actual_departure_time': {'epoch': 1560788160, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:16PM', 'date': '06/17/2019', 'localtime': 1560773760}, 'departure_delay': -900, 'filed_arrival_time': {'epoch': 1560791460, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:11PM', 'date': '06/17/2019', 'localtime': 1560777060}, 'estimated_arrival_time': {'epoch': 1560791160, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:06PM', 'date': '06/17/2019', 'localtime': 1560776760}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1200, 'status': 'En Route / On Time', 'progress_percent': 99, 'aircrafttype': 'E190', 'full_aircrafttype': 'E190', 'inbound_faFlightID': 'JBU508-1560605711-airline-0017', 'adhoc': False}, {'ident': 'DAL209', 'faFlightID': 'DAL209-1560592500-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '209', 'tailnumber': 'N707TW', 'type': 'Form_Airline', 'codeshares': 'VIR4027,KLM6152,AFR8635', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'EGPH', 'city': 'Edinburgh, Scotland', 'alternate_ident': 'EDI', 'airport_name': 'Edinburgh'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 25140, 'route': 'ENE PARCH3', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 474, 'distance_filed': 3279, 'filed_departure_time': {'epoch': 1560765300, 'tz': 'BST', 'dow': 'Monday', 'time': '10:55AM', 'date': '06/17/2019', 'localtime': 1560768900}, 'estimated_departure_time': {'epoch': 1560767651, 'tz': 'BST', 'dow': 'Monday', 'time': '11:34AM', 'date': '06/17/2019', 'localtime': 1560771251}, 'actual_departure_time': {'epoch': 1560767651, 'tz': 'BST', 'dow': 'Monday', 'time': '11:34AM', 'date': '06/17/2019', 'localtime': 1560771251}, 'departure_delay': 1751, 'filed_arrival_time': {'epoch': 1560790440, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:54PM', 'date': '06/17/2019', 'localtime': 1560776040}, 'estimated_arrival_time': {'epoch': 1560791160, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:06PM', 'date': '06/17/2019', 'localtime': 1560776760}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -840, 'status': 'En Route / On Time', 'progress_percent': 99, 'aircrafttype': 'B752', 'full_aircrafttype': 'B752', 'inbound_faFlightID': 'DAL122-1560519299-airline-0512', 'adhoc': False}, {'ident': 'CPA98', 'faFlightID': 'CPA98-1560596400-schedule-0000', 'airline': 'CPA', 'airline_iata': 'CX', 'flightnumber': '98', 'tailnumber': 'B-LJF', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'PANC', 'city': 'Anchorage, AK', 'alternate_ident': '', 'airport_name': 'Anchorage Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 23940, 'route': 'TED ELLAM NCA20 YRL J513 YXL SSM Q917 WOZEE Q935 HANKK Q140 YODAA IGN IGN1', 'filed_altitude': 350, 'display_filed_altitude': '35,000 feet', 'filed_airspeed_kts': 487, 'distance_filed': 3475, 'filed_departure_time': {'epoch': 1560769200, 'tz': 'AKDT', 'dow': 'Monday', 'time': '03:00AM', 'date': '06/17/2019', 'localtime': 1560740400}, 'estimated_departure_time': {'epoch': 1560768554, 'tz': 'AKDT', 'dow': 'Monday', 'time': '02:49AM', 'date': '06/17/2019', 'localtime': 1560739754}, 'actual_departure_time': {'epoch': 1560768554, 'tz': 'AKDT', 'dow': 'Monday', 'time': '02:49AM', 'date': '06/17/2019', 'localtime': 1560739754}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560793140, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:39PM', 'date': '06/17/2019', 'localtime': 1560778740}, 'estimated_arrival_time': {'epoch': 1560791220, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:07PM', 'date': '06/17/2019', 'localtime': 1560776820}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1920, 'status': 'En Route / On Time', 'progress_percent': 99, 'aircrafttype': 'B748', 'full_aircrafttype': 'B748', 'adhoc': False}, {'ident': 'DAL2498', 'faFlightID': 'DAL2498-1560612300-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2498', 'tailnumber': 'N955AT', 'type': 'Form_Airline', 'codeshares': 'WJA6837,WJA6837,VIR4692,VIR4692,AZA3396,AZA3396,AFR2169,AFR2169', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KCHS', 'city': 'Charleston, SC', 'alternate_ident': '', 'airport_name': 'Charleston Intl/AFB'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 5100, 'route': 'PLMTO2 BARTL J121 SIE CAMRN4', 'filed_altitude': 330, 'display_filed_altitude': '33,000 feet', 'filed_airspeed_kts': 453, 'distance_filed': 653, 'filed_departure_time': {'epoch': 1560785100, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:25AM', 'date': '06/17/2019', 'localtime': 1560770700}, 'estimated_departure_time': {'epoch': 1560786411, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:46AM', 'date': '06/17/2019', 'localtime': 1560772011}, 'actual_departure_time': {'epoch': 1560786411, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:46AM', 'date': '06/17/2019', 'localtime': 1560772011}, 'departure_delay': -60, 'filed_arrival_time': {'epoch': 1560790200, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:50PM', 'date': '06/17/2019', 'localtime': 1560775800}, 'estimated_arrival_time': {'epoch': 1560791280, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:08PM', 'date': '06/17/2019', 'localtime': 1560776880}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -780, 'status': 'En Route / On Time', 'progress_percent': 97, 'aircrafttype': 'B712', 'full_aircrafttype': 'B712', 'inbound_faFlightID': 'DAL2498-1560601200-schedule-0001', 'adhoc': False}, {'ident': 'DAL207', 'faFlightID': 'DAL207-1560595200-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '207', 'tailnumber': 'N821DX', 'type': 'Form_Airline', 'codeshares': 'KLM6153,AFR3674', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'EINN', 'city': 'Shannon, County Clare', 'alternate_ident': 'SNN', 'airport_name': 'Shannon'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 22440, 'route': 'JANJO N558A TAFFY ENE PARCH3', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 459, 'distance_filed': 3188, 'filed_departure_time': {'epoch': 1560768000, 'tz': 'IST', 'dow': 'Monday', 'time': '11:40AM', 'date': '06/17/2019', 'localtime': 1560771600}, 'estimated_departure_time': {'epoch': 1560768712, 'tz': 'IST', 'dow': 'Monday', 'time': '11:51AM', 'date': '06/17/2019', 'localtime': 1560772312}, 'actual_departure_time': {'epoch': 1560768712, 'tz': 'IST', 'dow': 'Monday', 'time': '11:51AM', 'date': '06/17/2019', 'localtime': 1560772312}, 'departure_delay': -60, 'filed_arrival_time': {'epoch': 1560790440, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:54PM', 'date': '06/17/2019', 'localtime': 1560776040}, 'estimated_arrival_time': {'epoch': 1560791460, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:11PM', 'date': '06/17/2019', 'localtime': 1560777060}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1680, 'status': 'En Route / On Time', 'progress_percent': 98, 'aircrafttype': 'B752', 'full_aircrafttype': 'B752', 'inbound_faFlightID': 'DAL206-1560519299-airline-0443', 'adhoc': False}, {'ident': 'DAL1310', 'faFlightID': 'DAL1310-1560605712-airline-0640', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '1310', 'tailnumber': 'N972AT', 'type': 'Form_Airline', 'codeshares': 'VIR4622,VIR4622,AZA3370,AZA3370,AFR2823,AFR2823,KLM5068,KLM5068,CES8808,CES8808,AMX4127', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KMSP', 'city': 'Minneapolis, MN', 'alternate_ident': '', 'airport_name': 'Minneapolis/St Paul Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 7320, 'route': 'COULT7 DLL HASTE DAFLU J70 STENT J70 MAGIO J70 LVZ LENDY6', 'filed_altitude': 330, 'display_filed_altitude': '33,000 feet', 'filed_airspeed_kts': 446, 'distance_filed': 1048, 'filed_departure_time': {'epoch': 1560784500, 'tz': 'CDT', 'dow': 'Monday', 'time': '10:15AM', 'date': '06/17/2019', 'localtime': 1560766500}, 'estimated_departure_time': {'epoch': 1560784433, 'tz': 'CDT', 'dow': 'Monday', 'time': '10:13AM', 'date': '06/17/2019', 'localtime': 1560766433}, 'actual_departure_time': {'epoch': 1560784433, 'tz': 'CDT', 'dow': 'Monday', 'time': '10:13AM', 'date': '06/17/2019', 'localtime': 1560766433}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560791820, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:17PM', 'date': '06/17/2019', 'localtime': 1560777420}, 'estimated_arrival_time': {'epoch': 1560791580, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:13PM', 'date': '06/17/2019', 'localtime': 1560777180}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1680, 'status': 'En Route / On Time', 'progress_percent': 93, 'aircrafttype': 'B712', 'full_aircrafttype': 'B712', 'inbound_faFlightID': 'DAL1639-1560597000-schedule-0000', 'adhoc': False}, {'ident': 'JBU510', 'faFlightID': 'JBU510-1560605711-airline-0158', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '510', 'tailnumber': 'N583JB', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'MDSD', 'city': 'Punta Caucedo', 'alternate_ident': 'SDQ', 'airport_name': 'Las Americas'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 12660, 'route': 'GOUGH L454 OKONU YAALE YETTI MOUGH DONAA OWENZ CAMRN', 'filed_altitude': 340, 'display_filed_altitude': '34,000 feet', 'filed_airspeed_kts': 463, 'distance_filed': 1605, 'filed_departure_time': {'epoch': 1560779700, 'tz': 'AST', 'dow': 'Monday', 'time': '09:55AM', 'date': '06/17/2019', 'localtime': 1560765300}, 'estimated_departure_time': {'epoch': 1560779556, 'tz': 'AST', 'dow': 'Monday', 'time': '09:52AM', 'date': '06/17/2019', 'localtime': 1560765156}, 'actual_departure_time': {'epoch': 1560779556, 'tz': 'AST', 'dow': 'Monday', 'time': '09:52AM', 'date': '06/17/2019', 'localtime': 1560765156}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560792360, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:26PM', 'date': '06/17/2019', 'localtime': 1560777960}, 'estimated_arrival_time': {'epoch': 1560791640, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:14PM', 'date': '06/17/2019', 'localtime': 1560777240}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1020, 'status': 'En Route / On Time', 'progress_percent': 95, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU209-1560589200-schedule-0000', 'adhoc': False}, {'ident': 'JBU26', 'faFlightID': 'JBU26-1560611280-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '26', 'tailnumber': 'N958JB', 'type': 'Form_Airline', 'codeshares': 'UAE6772,THY8552,SIA1470,RAM9519,QTR4164,ICE7856,ELY8759,EIN5089', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KTPA', 'city': 'Tampa, FL', 'alternate_ident': '', 'airport_name': 'Tampa Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 8460, 'route': 'BAYPO8 CAMJO Q109 PANDY BARTL J121 SIE CAMRN4', 'filed_altitude': 350, 'display_filed_altitude': '35,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1064, 'filed_departure_time': {'epoch': 1560784080, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:08AM', 'date': '06/17/2019', 'localtime': 1560769680}, 'estimated_departure_time': {'epoch': 1560784088, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:08AM', 'date': '06/17/2019', 'localtime': 1560769688}, 'actual_departure_time': {'epoch': 1560784088, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:08AM', 'date': '06/17/2019', 'localtime': 1560769688}, 'departure_delay': -660, 'filed_arrival_time': {'epoch': 1560792540, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:29PM', 'date': '06/17/2019', 'localtime': 1560778140}, 'estimated_arrival_time': {'epoch': 1560791640, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:14PM', 'date': '06/17/2019', 'localtime': 1560777240}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1080, 'status': 'En Route / On Time', 'progress_percent': 93, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU525-1560597300-schedule-0001', 'adhoc': False}, {'ident': 'JBU1404', 'faFlightID': 'JBU1404-1560606660-schedule-0000', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1404', 'tailnumber': 'N975JT', 'type': 'Form_Airline', 'codeshares': 'THY8532,ELY8736,EIN5343,QTR4158', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'TJSJ', 'city': 'San Juan, PR', 'alternate_ident': 'SJU', 'airport_name': 'Luis Munoz Marin Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 12720, 'route': 'GLADA3 PRCHA L456 VINSO L456 DARUX L459 SAVIK YETTI MOUGH DONAA OWENZ CAMRN', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 451, 'distance_filed': 1667, 'filed_departure_time': {'epoch': 1560779460, 'tz': 'AST', 'dow': 'Monday', 'time': '09:51AM', 'date': '06/17/2019', 'localtime': 1560765060}, 'estimated_departure_time': {'epoch': 1560779752, 'tz': 'AST', 'dow': 'Monday', 'time': '09:55AM', 'date': '06/17/2019', 'localtime': 1560765352}, 'actual_departure_time': {'epoch': 1560779752, 'tz': 'AST', 'dow': 'Monday', 'time': '09:55AM', 'date': '06/17/2019', 'localtime': 1560765352}, 'departure_delay': -420, 'filed_arrival_time': {'epoch': 1560792180, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:23PM', 'date': '06/17/2019', 'localtime': 1560777780}, 'estimated_arrival_time': {'epoch': 1560791760, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:16PM', 'date': '06/17/2019', 'localtime': 1560777360}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -960, 'status': 'En Route / On Time', 'progress_percent': 94, 'aircrafttype': 'A321', 'full_aircrafttype': 'A321', 'inbound_faFlightID': 'JBU1403-1560589200-schedule-0000', 'adhoc': False}, {'ident': 'DAL1994', 'faFlightID': 'DAL1994-1560603600-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '1994', 'tailnumber': 'N869DN', 'type': 'Form_Airline', 'codeshares': 'VIR4800,KLM7405,AZA3155,AFL3487,AEA3418,AFR8923', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KPHX', 'city': 'Phoenix, AZ', 'alternate_ident': '', 'airport_name': 'Phoenix Sky Harbor Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 14940, 'route': 'FORPE1 ABQ TBE LNK FOD KG75M DAFLU J70 STENT J70 MAGIO J70 LVZ LENDY6', 'filed_altitude': 330, 'display_filed_altitude': '33,000 feet', 'filed_airspeed_kts': 463, 'distance_filed': 2250, 'filed_departure_time': {'epoch': 1560776400, 'tz': 'MST', 'dow': 'Monday', 'time': '06:00AM', 'date': '06/17/2019', 'localtime': 1560751200}, 'estimated_departure_time': {'epoch': 1560777080, 'tz': 'MST', 'dow': 'Monday', 'time': '06:11AM', 'date': '06/17/2019', 'localtime': 1560751880}, 'actual_departure_time': {'epoch': 1560777080, 'tz': 'MST', 'dow': 'Monday', 'time': '06:11AM', 'date': '06/17/2019', 'localtime': 1560751880}, 'departure_delay': -60, 'filed_arrival_time': {'epoch': 1560791340, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:09PM', 'date': '06/17/2019', 'localtime': 1560776940}, 'estimated_arrival_time': {'epoch': 1560791760, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:16PM', 'date': '06/17/2019', 'localtime': 1560777360}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -960, 'status': 'En Route / On Time', 'progress_percent': 95, 'aircrafttype': 'B739', 'full_aircrafttype': 'B739', 'inbound_faFlightID': 'DAL2209-1560519299-airline-0268', 'adhoc': False}, {'ident': 'DAL630', 'faFlightID': 'DAL630-1560603600-schedule-0000', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '630', 'tailnumber': 'N808DN', 'type': 'Form_Airline', 'codeshares': 'VIR4774,VIR4774,KLM5681,KLM5681,CES4170,CES4170,AZA3276,AZA3276,AFL3465,AFL3465,AEA3330,AEA3330', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KLAS', 'city': 'Las Vegas, NV', 'alternate_ident': '', 'airport_name': 'McCarran Intl'}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 15120, 'route': 'STAAV8 DVC FQF J10 OBH FOD KG75M DAFLU J70 STENT J70 MAGIO J70 LVZ LENDY6', 'filed_altitude': 330, 'display_filed_altitude': '33,000 feet', 'filed_airspeed_kts': 464, 'distance_filed': 2309, 'filed_departure_time': {'epoch': 1560776400, 'tz': 'PDT', 'dow': 'Monday', 'time': '06:00AM', 'date': '06/17/2019', 'localtime': 1560751200}, 'estimated_departure_time': {'epoch': 1560777012, 'tz': 'PDT', 'dow': 'Monday', 'time': '06:10AM', 'date': '06/17/2019', 'localtime': 1560751812}, 'actual_departure_time': {'epoch': 1560777012, 'tz': 'PDT', 'dow': 'Monday', 'time': '06:10AM', 'date': '06/17/2019', 'localtime': 1560751812}, 'departure_delay': -240, 'filed_arrival_time': {'epoch': 1560791520, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:12PM', 'date': '06/17/2019', 'localtime': 1560777120}, 'estimated_arrival_time': {'epoch': 1560792000, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:20PM', 'date': '06/17/2019', 'localtime': 1560777600}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1620, 'status': 'En Route / On Time', 'progress_percent': 94, 'aircrafttype': 'B739', 'full_aircrafttype': 'B739', 'inbound_faFlightID': 'DAL2661-1560519299-airline-0405', 'adhoc': False}, {'ident': 'AAL67', 'faFlightID': 'AAL67-1560590100-schedule-0000', 'airline': 'AAL', 'airline_iata': 'AA', 'flightnumber': '67', 'tailnumber': 'N780AN', 'type': 'Form_Airline', 'codeshares': 'IBE4186,FIN4003,ELY8001,BAW1557', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'LEBL', 'city': 'Barcelona', 'alternate_ident': 'BCN', 'airport_name': "Barcelona Int'l"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 28620, 'route': 'GRAUS UM601 MARIO UM601 RONNY UM601 BLV UM190 LASKU VES BEGAS 4600N/02000W 4700N/03000W 4700N/04000W 4400N/05000W 4200N/06000W DOVEY N20B SAILE ACK SEY PARCH3', 'filed_altitude': 400, 'display_filed_altitude': '40,000 feet', 'filed_airspeed_kts': 489, 'distance_filed': 3893, 'filed_departure_time': {'epoch': 1560762900, 'tz': 'CEST', 'dow': 'Monday', 'time': '11:15AM', 'date': '06/17/2019', 'localtime': 1560770100}, 'estimated_departure_time': {'epoch': 1560763620, 'tz': 'CEST', 'dow': 'Monday', 'time': '11:27AM', 'date': '06/17/2019', 'localtime': 1560770820}, 'actual_departure_time': {'epoch': 1560763620, 'tz': 'CEST', 'dow': 'Monday', 'time': '11:27AM', 'date': '06/17/2019', 'localtime': 1560770820}, 'departure_delay': -120, 'filed_arrival_time': {'epoch': 1560791520, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:12PM', 'date': '06/17/2019', 'localtime': 1560777120}, 'estimated_arrival_time': {'epoch': 1560792001, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:20PM', 'date': '06/17/2019', 'localtime': 1560777601}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1140, 'status': 'En Route / On Time', 'progress_percent': 96, 'aircrafttype': 'B772', 'full_aircrafttype': 'B772', 'inbound_faFlightID': 'AAL112-1560519291-airline-0634', 'adhoc': False}, {'ident': 'DLH400', 'faFlightID': 'DLH400-1560589200-schedule-0001', 'airline': 'DLH', 'airline_iata': 'LH', 'flightnumber': '400', 'tailnumber': 'D-AIML', 'type': 'Form_Airline', 'codeshares': 'UAL8841,THA7700,ETH1610,BEL7230', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'EDDF', 'city': 'Frankfurt am Main', 'alternate_ident': 'FRA', 'airport_name': "Frankfurt Int'l"}, 'destination': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'filed_ete': 26760, 'route': 'TAFFY ENE PARCH3', 'filed_altitude': 400, 'display_filed_altitude': '40,000 feet', 'filed_airspeed_kts': 476, 'distance_filed': 3911, 'filed_departure_time': {'epoch': 1560762000, 'tz': 'CEST', 'dow': 'Monday', 'time': '11:00AM', 'date': '06/17/2019', 'localtime': 1560769200}, 'estimated_departure_time': {'epoch': 1560765874, 'tz': 'CEST', 'dow': 'Monday', 'time': '12:04PM', 'date': '06/17/2019', 'localtime': 1560773074}, 'actual_departure_time': {'epoch': 1560765874, 'tz': 'CEST', 'dow': 'Monday', 'time': '12:04PM', 'date': '06/17/2019', 'localtime': 1560773074}, 'departure_delay': 2820, 'filed_arrival_time': {'epoch': 1560788760, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:26PM', 'date': '06/17/2019', 'localtime': 1560774360}, 'estimated_arrival_time': {'epoch': 1560792035, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:20PM', 'date': '06/17/2019', 'localtime': 1560777635}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 2820, 'status': 'En Route / Delayed', 'progress_percent': 96, 'aircrafttype': 'A388', 'full_aircrafttype': 'A388', 'adhoc': False}]}, 'scheduled': {'num_flights': 15, 'next_offset': 15, 'flights': [{'ident': 'DAL2175', 'faFlightID': 'DAL2175-1560605712-airline-0383', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '2175', 'tailnumber': 'N328NW', 'type': 'Form_Airline', 'codeshares': 'VIR4831,VIR4831,KQA7014,KQA7014,GLO8078,GLO8078,AZA5826,AZA5826,ARG7089,ARG7089', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KMIA', 'city': 'Miami, FL', 'alternate_ident': '', 'airport_name': 'Miami Intl'}, 'filed_ete': 10020, 'route': 'WAVEY EMJAY J174 ORF J121 BARTL JROSS Q409 ENEME Q65 DOFFY JUULI SSCOT5', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 471, 'distance_filed': 1093, 'filed_departure_time': {'epoch': 1560785700, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:35AM', 'date': '06/17/2019', 'localtime': 1560771300}, 'estimated_departure_time': {'epoch': 1560785100, 'tz': 'EDT', 'dow': 'Monday', 'time': '11:25AM', 'date': '06/17/2019', 'localtime': 1560770700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 7500, 'filed_arrival_time': {'epoch': 1560795720, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:22PM', 'date': '06/17/2019', 'localtime': 1560781320}, 'estimated_arrival_time': {'epoch': 1560795120, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:12PM', 'date': '06/17/2019', 'localtime': 1560780720}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 7260, 'status': 'Scheduled / Delayed', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'DAL2464-1560598800-schedule-0001', 'adhoc': False}, {'ident': 'AAL3957', 'faFlightID': 'AAL3957-1560605721-airline-0261', 'airline': 'AAL', 'airline_iata': 'AA', 'flightnumber': '3957', 'type': 'Form_Airline', 'codeshares': 'TAM2230,LAN6991', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'CYYZ', 'city': 'Toronto, Ontario', 'alternate_ident': '', 'airport_name': "Toronto Pearson Int'l"}, 'filed_ete': 5160, 'filed_airspeed_kts': 222, 'distance_filed': 366, 'filed_departure_time': {'epoch': 1560788100, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:15PM', 'date': '06/17/2019', 'localtime': 1560773700}, 'estimated_departure_time': {'epoch': 1560788100, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:15PM', 'date': '06/17/2019', 'localtime': 1560773700}, 'actual_departure_time': {'epoch': 0}, 'filed_arrival_time': {'epoch': 1560793260, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:41PM', 'date': '06/17/2019', 'localtime': 1560778860}, 'estimated_arrival_time': {'epoch': 1560793260, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:41PM', 'date': '06/17/2019', 'localtime': 1560778860}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'E145', 'full_aircrafttype': 'E145', 'adhoc': False}, {'ident': 'EDV3492', 'faFlightID': 'EDV3492-1560605736-airline-0045', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '3492', 'tailnumber': 'N925XJ', 'type': 'Form_Airline', 'codeshares': 'AZA3251,AZA3251,ARG7032,ARG7032,KLM7448,DAL3492,AFR8557', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KORD', 'city': 'Chicago, IL', 'alternate_ident': '', 'airport_name': "Chicago O'Hare Intl"}, 'filed_ete': 12420, 'route': 'COATE Q436 EMMMA WYNDE9', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 475, 'distance_filed': 739, 'filed_departure_time': {'epoch': 1560789000, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:30PM', 'date': '06/17/2019', 'localtime': 1560774600}, 'estimated_departure_time': {'epoch': 1560789000, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:30PM', 'date': '06/17/2019', 'localtime': 1560774600}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 2940, 'filed_arrival_time': {'epoch': 1560801420, 'tz': 'CDT', 'dow': 'Monday', 'time': '02:57PM', 'date': '06/17/2019', 'localtime': 1560783420}, 'estimated_arrival_time': {'epoch': 1560801420, 'tz': 'CDT', 'dow': 'Monday', 'time': '02:57PM', 'date': '06/17/2019', 'localtime': 1560783420}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 3600, 'status': 'Scheduled / Delayed', 'progress_percent': -1, 'aircrafttype': 'CRJ9', 'full_aircrafttype': 'CRJ9', 'inbound_faFlightID': 'EDV5538-1560605736-airline-0044', 'adhoc': False}, {'ident': 'AAL291', 'faFlightID': 'AAL291-1560603154-airline-0503', 'airline': 'AAL', 'airline_iata': 'AA', 'flightnumber': '291', 'tailnumber': 'N392AN', 'type': 'Form_Airline', 'codeshares': 'MAS9446,JAL7470,BAW5089,DSM6384,TAM2004,LAN6515', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KMIA', 'city': 'Miami, FL', 'alternate_ident': '', 'airport_name': 'Miami Intl'}, 'filed_ete': 10260, 'route': 'WAVEY EMJAY J174 ORF J121 BARTL JROSS Q409 ENEME Q65 DOFFY JUULI SSCOT5', 'filed_altitude': 360, 'display_filed_altitude': '36,000 feet', 'filed_airspeed_kts': 471, 'distance_filed': 1093, 'filed_departure_time': {'epoch': 1560791340, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:09PM', 'date': '06/17/2019', 'localtime': 1560776940}, 'estimated_departure_time': {'epoch': 1560790740, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:59PM', 'date': '06/17/2019', 'localtime': 1560776340}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -420, 'filed_arrival_time': {'epoch': 1560801600, 'tz': 'EDT', 'dow': 'Monday', 'time': '04:00PM', 'date': '06/17/2019', 'localtime': 1560787200}, 'estimated_arrival_time': {'epoch': 1560801000, 'tz': 'EDT', 'dow': 'Monday', 'time': '03:50PM', 'date': '06/17/2019', 'localtime': 1560786600}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -360, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'B763', 'full_aircrafttype': 'B763', 'inbound_faFlightID': 'AAL291-1560516516-airline-0069', 'adhoc': False}, {'ident': 'RPA5992', 'faFlightID': 'RPA5992-1560605713-airline-0250', 'airline': 'RPA', 'airline_iata': 'YX', 'flightnumber': '5992', 'tailnumber': 'N878RW', 'type': 'Form_Airline', 'codeshares': 'VIR3500,ARG7073,DAL5992,DAL5992,WJA6515', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KDCA', 'city': 'Washington, DC', 'alternate_ident': '', 'airport_name': 'Reagan National'}, 'filed_ete': 2820, 'route': 'RBV J230 COPES J75 MXE CLIPR2', 'filed_altitude': 180, 'display_filed_altitude': '18,000 feet', 'filed_airspeed_kts': 385, 'distance_filed': 213, 'filed_departure_time': {'epoch': 1560791340, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:09PM', 'date': '06/17/2019', 'localtime': 1560776940}, 'estimated_departure_time': {'epoch': 1560791040, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:04PM', 'date': '06/17/2019', 'localtime': 1560776640}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560794160, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:56PM', 'date': '06/17/2019', 'localtime': 1560779760}, 'estimated_arrival_time': {'epoch': 1560793860, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:51PM', 'date': '06/17/2019', 'localtime': 1560779460}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1200, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'E170', 'full_aircrafttype': 'E170', 'inbound_faFlightID': 'RPA5957-1560605736-airline-0080', 'adhoc': False}, {'ident': 'ASA237', 'faFlightID': 'ASA237-1560618019-airline-0194', 'airline': 'ASA', 'airline_iata': 'AS', 'flightnumber': '237', 'tailnumber': 'N457AS', 'type': 'Form_Airline', 'codeshares': 'SIA1415', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KLAX', 'city': 'Los Angeles, CA', 'alternate_ident': '', 'airport_name': 'Los Angeles Intl'}, 'filed_ete': 20400, 'route': 'RBV J230 AIR J110 VHP KK57I KD45U JASSE Q90 AREAF Q90 DNERO ANJLL4', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 462, 'distance_filed': 2472, 'filed_departure_time': {'epoch': 1560791400, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:10PM', 'date': '06/17/2019', 'localtime': 1560777000}, 'estimated_departure_time': {'epoch': 1560791040, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:04PM', 'date': '06/17/2019', 'localtime': 1560776640}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -360, 'filed_arrival_time': {'epoch': 1560811800, 'tz': 'PDT', 'dow': 'Monday', 'time': '03:50PM', 'date': '06/17/2019', 'localtime': 1560786600}, 'estimated_arrival_time': {'epoch': 1560811440, 'tz': 'PDT', 'dow': 'Monday', 'time': '03:44PM', 'date': '06/17/2019', 'localtime': 1560786240}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -960, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'B739', 'full_aircrafttype': 'B739', 'inbound_faFlightID': 'ASA426-1560519295-airline-0198', 'adhoc': False}, {'ident': 'EDV3409', 'faFlightID': 'EDV3409-1560605717-airline-0189', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '3409', 'tailnumber': 'N326PQ', 'type': 'Form_Airline', 'codeshares': 'GLO8194,GLO8194,AMX3969,AMX3969,KLM8233,KLM8233,DAL3409,AFR2667', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KDTW', 'city': 'Detroit, MI', 'alternate_ident': '', 'airport_name': 'Detroit Metro Wayne Co'}, 'filed_ete': 5520, 'route': 'GAYEL J95 CFB BUF YQO SVM', 'filed_altitude': 300, 'display_filed_altitude': '30,000 feet', 'filed_airspeed_kts': 480, 'distance_filed': 508, 'filed_departure_time': {'epoch': 1560791340, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:09PM', 'date': '06/17/2019', 'localtime': 1560776940}, 'estimated_departure_time': {'epoch': 1560791100, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:05PM', 'date': '06/17/2019', 'localtime': 1560776700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -240, 'filed_arrival_time': {'epoch': 1560796860, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:41PM', 'date': '06/17/2019', 'localtime': 1560782460}, 'estimated_arrival_time': {'epoch': 1560796620, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:37PM', 'date': '06/17/2019', 'localtime': 1560782220}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -960, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'CRJ9', 'full_aircrafttype': 'CRJ9', 'inbound_faFlightID': 'EDV5243-1560602040-schedule-0000', 'adhoc': False}, {'ident': 'KQA3', 'faFlightID': 'KQA3-1560605721-airline-0035', 'airline': 'KQA', 'airline_iata': 'KQ', 'flightnumber': '3', 'tailnumber': '5Y-KZF', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'HKJK', 'city': 'Nairobi', 'alternate_ident': 'NBO', 'airport_name': "Jomo Kenyatta Int'l"}, 'filed_ete': 51000, 'route': 'ACK VITOL N21A CARAC JEBBY 4300N/05000W 4100N/04000W 3900N/03000W 3800N/02000W KOMUT SONAP ORTOP UN726 BAMBA UA621 ARI UL58 XAVOV UM999 MNA UB730 DIR UG862 ONUDA UG862 BUN UW325 NN UL433 NAKAT NAKAT2P', 'filed_altitude': 370, 'display_filed_altitude': '37,000 feet', 'filed_airspeed_kts': 486, 'distance_filed': 7363, 'filed_departure_time': {'epoch': 1560791100, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:05PM', 'date': '06/17/2019', 'localtime': 1560776700}, 'estimated_departure_time': {'epoch': 1560791100, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:05PM', 'date': '06/17/2019', 'localtime': 1560776700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560842100, 'tz': 'EAT', 'dow': 'Tuesday', 'time': '10:15AM', 'date': '06/18/2019', 'localtime': 1560852900}, 'estimated_arrival_time': {'epoch': 1560842100, 'tz': 'EAT', 'dow': 'Tuesday', 'time': '10:15AM', 'date': '06/18/2019', 'localtime': 1560852900}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 0, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'B788', 'full_aircrafttype': 'B788', 'adhoc': False}, {'ident': 'EDV5374', 'faFlightID': 'EDV5374-1560605736-airline-0110', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5374', 'tailnumber': 'N298PQ', 'type': 'Form_Airline', 'codeshares': 'WJA7658,KLM6966,KAL3949,AZA5283,ARG7071,AFR5949,DAL5374,DAL5374,DAL5374,GLO8322', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KBOS', 'city': 'Boston, MA', 'alternate_ident': '', 'airport_name': 'Boston Logan Intl'}, 'filed_ete': 2820, 'route': 'MERIT ROBUC3', 'filed_altitude': 150, 'display_filed_altitude': '15,000 feet', 'filed_airspeed_kts': 380, 'distance_filed': 187, 'filed_departure_time': {'epoch': 1560791340, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:09PM', 'date': '06/17/2019', 'localtime': 1560776940}, 'estimated_departure_time': {'epoch': 1560791100, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:05PM', 'date': '06/17/2019', 'localtime': 1560776700}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -240, 'filed_arrival_time': {'epoch': 1560794160, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:56PM', 'date': '06/17/2019', 'localtime': 1560779760}, 'estimated_arrival_time': {'epoch': 1560793920, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:52PM', 'date': '06/17/2019', 'localtime': 1560779520}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1200, 'status': 'Taxiing / Left Gate', 'progress_percent': -1, 'aircrafttype': 'CRJ9', 'full_aircrafttype': 'CRJ9', 'inbound_faFlightID': 'EDV5428-1560605727-airline-0053', 'adhoc': False}, {'ident': 'JBU1591', 'faFlightID': 'JBU1591-1560605711-airline-0432', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '1591', 'tailnumber': 'N184JB', 'type': 'Form_Airline', 'codeshares': 'HAL2092,QTR4009', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KACK', 'city': 'Nantucket, MA', 'alternate_ident': '', 'airport_name': 'Nantucket Memorial'}, 'filed_ete': 4260, 'route': 'BAYYS SEALL V188 GON DEEPO1', 'filed_altitude': 210, 'display_filed_altitude': '21,000 feet', 'filed_airspeed_kts': 372, 'distance_filed': 199, 'filed_departure_time': {'epoch': 1560791820, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:17PM', 'date': '06/17/2019', 'localtime': 1560777420}, 'estimated_departure_time': {'epoch': 1560791220, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:07PM', 'date': '06/17/2019', 'localtime': 1560776820}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560796080, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:28PM', 'date': '06/17/2019', 'localtime': 1560781680}, 'estimated_arrival_time': {'epoch': 1560795480, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:18PM', 'date': '06/17/2019', 'localtime': 1560781080}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -420, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'E190', 'full_aircrafttype': 'E190', 'inbound_faFlightID': 'JBU1492-1560598800-schedule-0000', 'adhoc': False}, {'ident': 'EDV5294', 'faFlightID': 'EDV5294-1560605736-airline-0004', 'airline': 'EDV', 'airline_iata': '9E', 'flightnumber': '5294', 'tailnumber': 'N200PQ', 'type': 'Form_Airline', 'codeshares': 'WJA6884,WJA6884,DAL5294,DAL5294,DAL5294,AZA5843,AZA5843,AFR2552,AFR2141', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KRDU', 'city': 'Raleigh/Durham, NC', 'alternate_ident': '', 'airport_name': 'Raleigh-Durham Intl'}, 'filed_ete': 4200, 'route': 'WAVEY EMJAY J174 SWL KAROO2', 'filed_altitude': 320, 'display_filed_altitude': '32,000 feet', 'filed_airspeed_kts': 475, 'distance_filed': 427, 'filed_departure_time': {'epoch': 1560792120, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:22PM', 'date': '06/17/2019', 'localtime': 1560777720}, 'estimated_departure_time': {'epoch': 1560791820, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:17PM', 'date': '06/17/2019', 'localtime': 1560777420}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560796320, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:32PM', 'date': '06/17/2019', 'localtime': 1560781920}, 'estimated_arrival_time': {'epoch': 1560796020, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:27PM', 'date': '06/17/2019', 'localtime': 1560781620}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1620, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'CRJ9', 'full_aircrafttype': 'CRJ9', 'inbound_faFlightID': 'EDV5256-1560605736-airline-0091', 'adhoc': False}, {'ident': 'DAL495', 'faFlightID': 'DAL495-1560605712-airline-0271', 'airline': 'DAL', 'airline_iata': 'DL', 'flightnumber': '495', 'tailnumber': 'N899DN', 'type': 'Form_Airline', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'MDSD', 'city': 'Punta Caucedo', 'alternate_ident': 'SDQ', 'airport_name': 'Las Americas'}, 'filed_ete': 11160, 'route': 'SHIPP JETZZ BLUUU DUMPR ICCEY OHRYN BEHHR ROLLE ATUGI L454 LUCTI L454 MNDEZ POKEG UT17 KOBET CDO', 'filed_altitude': 330, 'display_filed_altitude': '33,000 feet', 'filed_airspeed_kts': 468, 'distance_filed': 1556, 'filed_departure_time': {'epoch': 1560792000, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:20PM', 'date': '06/17/2019', 'localtime': 1560777600}, 'estimated_departure_time': {'epoch': 1560792000, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:20PM', 'date': '06/17/2019', 'localtime': 1560777600}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': -300, 'filed_arrival_time': {'epoch': 1560803160, 'tz': 'AST', 'dow': 'Monday', 'time': '04:26PM', 'date': '06/17/2019', 'localtime': 1560788760}, 'estimated_arrival_time': {'epoch': 1560803160, 'tz': 'AST', 'dow': 'Monday', 'time': '04:26PM', 'date': '06/17/2019', 'localtime': 1560788760}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -1320, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'B739', 'full_aircrafttype': 'B739', 'inbound_faFlightID': 'DAL2543-1560600180-schedule-0000', 'adhoc': False}, {'ident': 'JBU34', 'faFlightID': 'JBU34-1560605711-airline-0167', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '34', 'tailnumber': 'N524JB', 'type': 'Form_Airline', 'codeshares': 'UAE6707,QTR4063,HAL2062', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KBTV', 'city': 'Burlington, VT', 'alternate_ident': '', 'airport_name': 'Burlington Intl'}, 'filed_ete': 3360, 'route': 'GREKI JUDDS CAM', 'filed_altitude': 270, 'display_filed_altitude': '27,000 feet', 'filed_airspeed_kts': 470, 'distance_filed': 267, 'filed_departure_time': {'epoch': 1560789540, 'tz': 'EDT', 'dow': 'Monday', 'time': '12:39PM', 'date': '06/17/2019', 'localtime': 1560775140}, 'estimated_departure_time': {'epoch': 1560792300, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:25PM', 'date': '06/17/2019', 'localtime': 1560777900}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 2760, 'filed_arrival_time': {'epoch': 1560792900, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:35PM', 'date': '06/17/2019', 'localtime': 1560778500}, 'estimated_arrival_time': {'epoch': 1560795660, 'tz': 'EDT', 'dow': 'Monday', 'time': '02:21PM', 'date': '06/17/2019', 'localtime': 1560781260}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': 2700, 'status': 'Scheduled / Delayed', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU1274-1560605460-schedule-0000', 'adhoc': False}, {'ident': 'JBU803', 'faFlightID': 'JBU803-1560605711-airline-0056', 'airline': 'JBU', 'airline_iata': 'B6', 'flightnumber': '803', 'tailnumber': 'N705JB', 'type': 'Form_Airline', 'codeshares': 'UAE6815,THY8991,JAL5482,QTR4159', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'TJSJ', 'city': 'San Juan, PR', 'alternate_ident': 'SJU', 'airport_name': 'Luis Munoz Marin Intl'}, 'filed_ete': 13560, 'route': 'SHIPP JETZZ BLUUU DUMPR ICCEY OHRYN BEHHR RESQU SKPPR L455 KINCH L455 LENNT A300 PLING RTE7 SAALR', 'filed_altitude': 370, 'display_filed_altitude': '37,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 1642, 'filed_departure_time': {'epoch': 1560793140, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:39PM', 'date': '06/17/2019', 'localtime': 1560778740}, 'estimated_departure_time': {'epoch': 1560792540, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:29PM', 'date': '06/17/2019', 'localtime': 1560778140}, 'actual_departure_time': {'epoch': 0}, 'filed_arrival_time': {'epoch': 1560806700, 'tz': 'AST', 'dow': 'Monday', 'time': '05:25PM', 'date': '06/17/2019', 'localtime': 1560792300}, 'estimated_arrival_time': {'epoch': 1560806100, 'tz': 'AST', 'dow': 'Monday', 'time': '05:15PM', 'date': '06/17/2019', 'localtime': 1560791700}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'A320', 'full_aircrafttype': 'A320', 'inbound_faFlightID': 'JBU520-1560605711-airline-0020', 'adhoc': False}, {'ident': 'AAL952', 'faFlightID': 'AAL952-1560605709-airline-0190', 'airline': 'AAL', 'airline_iata': 'AA', 'flightnumber': '952', 'tailnumber': 'N803NN', 'type': 'Form_Airline', 'codeshares': 'CSN1693,TAM2384,FIN4080', 'blocked': False, 'diverted': False, 'cancelled': False, 'origin': {'code': 'KJFK', 'city': 'New York, NY', 'alternate_ident': '', 'airport_name': 'John F Kennedy Intl'}, 'destination': {'code': 'KPHX', 'city': 'Phoenix, AZ', 'alternate_ident': '', 'airport_name': 'Phoenix Sky Harbor Intl'}, 'filed_ete': 16920, 'route': 'RBV J230 AIR J80 MCI J24 SLN J96 CIM ZUN EAGUL6', 'filed_altitude': 220, 'display_filed_altitude': '22,000 feet', 'filed_airspeed_kts': 456, 'distance_filed': 2151, 'filed_departure_time': {'epoch': 1560793200, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:40PM', 'date': '06/17/2019', 'localtime': 1560778800}, 'estimated_departure_time': {'epoch': 1560792600, 'tz': 'EDT', 'dow': 'Monday', 'time': '01:30PM', 'date': '06/17/2019', 'localtime': 1560778200}, 'actual_departure_time': {'epoch': 0}, 'departure_delay': 0, 'filed_arrival_time': {'epoch': 1560810120, 'tz': 'MST', 'dow': 'Monday', 'time': '03:22PM', 'date': '06/17/2019', 'localtime': 1560784920}, 'estimated_arrival_time': {'epoch': 1560809520, 'tz': 'MST', 'dow': 'Monday', 'time': '03:12PM', 'date': '06/17/2019', 'localtime': 1560784320}, 'actual_arrival_time': {'epoch': 0}, 'arrival_delay': -600, 'status': 'Scheduled', 'progress_percent': -1, 'aircrafttype': 'B738', 'full_aircrafttype': 'B738', 'inbound_faFlightID': 'AAL2287-1560602220-schedule-0000', 'adhoc': False}]}}}
        self.stubbed_count_aiport_operations_response = {'CountAirportOperationsResult': {'enroute': 831, 'departed': 103, 'scheduled_departures': 1691, 'scheduled_arrivals': 1644}}
        self.stubbed_get_aircraft_type_response = {'AircraftTypeResult': {'manufacturer': 'Boeing', 'type': '747-200', 'description': 'quad-jet', 'engine_count': 4, 'engine_type': 'jet'}}
        self.stubbed_get_airport_info_response = {'AirportInfoResult': {'airport_code': 'KJFK', 'name': 'John F Kennedy Intl', 'elevation': 12, 'city': 'New York', 'state': 'NY', 'longitude': -73.778695, 'latitude': 40.6399257, 'timezone': ':America/New_York', 'country_code': 'US', 'wiki_url': 'http://en.wikipedia.org/wiki/John_F_Kennedy_International', 'alternate_ident': 'JFK'}}

        if (self.is_production and self.cache_enabled):
            self.flight_aware_cache = Cache(maxsize=200, ttl=300, timer=time.time, default=None)

    def __make_request(self, end_point, payload):
        key = str(payload)
        response = self.flight_aware_cache.get(key) if self.cache_enabled else None
        if (response == None):
            print("Cache Miss!")
            response = requests.get(self.FXML_URL + end_point, params=payload, auth=self.authentication_info)

            if self.cache_enabled:
                self.flight_aware_cache.add(key, response)
        else:
            print("Cache Hit!")

        if response.status_code == 200:
            decodedResponse = response.json()
            return decodedResponse
        else:
            print("Unable to retrieve flight aware data", response.text)
            return RuntimeError("Unable to retrieve flight aware data")

    def find_flight_cancellation_statistics(self, time_period, type_matching, ident_filter):
        '''
        find_flight_cancellation_statistics fetches statistics about how many flights have been cancelled on the
        specified day, and aggregated by the specified breakdown criteria. Currently supported criteria include the
        operating airline, the origin airport, or the destination airport.

        :param time_period: (must be 'yesterday', 'today', 'tomorrow', 'plus2days', 'twoDaysAgo', 'minus2plus12hrs', 'next36hrs', 'week')
        :param type_matching: (must be 'airline', 'origin', or 'destination')
        :param ident_filter: this argument can be blank/unspecified to request that all results are returned. Otherwise,
            when type_matching is 'airline', this argument can be the specific airline you are interested in.
            When type_matching is 'origin' or 'destination', this argument can be the specific airport you are interested in.
        :return: CancellationSummaryStruct
        '''

        if (self.is_production):
            payload = {'time_period': time_period, 'type_matching': type_matching, 'ident_filter': ident_filter}
            return self.__make_request('FlightCancellationStatistics', payload)
        else:
            return self.stubbed_find_flight_cancellation_statistics_response

    def find_airline_info(self, airline_code):
        '''
        find_airline_info returns information about a commercial airline/carrier given an ICAO airline code.

        :param airline_code: the ICAO airline ID (e.g., COA, ASA, UAL, etc.)
        :return: AirlineInfoStruct
        '''

        if (self.is_production):
            payload = {'airline_code': airline_code}
            return self.__make_request('AirlineInfo', payload)
        else:
            return self.stubbed_find_airline_info_response


    def __find_airport_boards_base(self, payload):
        if not payload['type'] in ["arrivals", "departures", "enroute", "scheduled", "all"]:
            payload['type'] = "all"

        if (self.is_production):
            return self.__make_request('AirportBoards', payload)
        else:
            return self.stubbed_find_airport_boards_response


    def find_airport_boards(self, airport_code, type):
        '''
        find_airport_boards returns the flights scheduled, departing, enroute, and arriving at a specified airport.

        :param airport_code: the ICAO airport ID (e.g., KLAX, KSFO, KIAH, KHOU, KJFK, KEWR, KORD, KATL, etc.)
        :param type: Select "all" or any space separated combination of "arrivals", "departures", "enroute", and "scheduled". Defaults to all
        :return: AirportBoardsStruct
        '''
        payload = {'airport_code': airport_code, 'filter': 'airline', 'type': type}
        return self.__find_airport_boards_base(payload)


    def find_airport_boards_with_specific_airlines(self, airport_code, airline_code, type):
        '''
        find_airport_boards_with_specific_airlines returns the flights scheduled, departing, enroute,
        and arriving at a specified airport and airline.

        :param airport_code: the ICAO airport ID (e.g., KLAX, KSFO, KIAH, KHOU, KJFK, KEWR, KORD, KATL, etc.)
        :param airline_code: the ICAO airline ID (e.g., COA, ASA, UAL, etc.)
        :param type: Select "all" or any space separated combination of "arrivals", "departures", "enroute", and "scheduled". Defaults to all
        :return: AirportBoardsStruct
        '''

        payload = {'airport_code': airport_code, 'filter': 'airline:'+airline_code, 'type': type}
        return self.__find_airport_boards_base(payload)


    def find_flights_with_airline_info(self, airline_info):
        '''
        find_flights_with_airline_info returns information about flights for a specific tail number (e.g., N12345), or an ident
        (typically an ICAO airline with flight number, e.g., SWA2558), or a FlightAware-assigned unique flight identifier
        (e.g. faFlightID returned by another FlightXML function). When a tail number or ident is specified and multiple
        flights are available, the results will be returned from newest to oldest. The oldest flights searched by this
        function are about 2 weeks in the past.	Codeshares and alternate idents are automatically searched.
        When a FlightAware-assigned unique flight identifier is supplied, at most a single result will be returned.

        :param airline_info: 'DAL127'
        :return: list of flights that match the flight #
        '''

        if (self.is_production):
            payload = {'ident': airline_info}
            response = self.__make_request('FlightInfoStatus', payload)
            return response
        else:
            return self.stubbed_find_flights_with_airline_info_response

    def find_flights_using_origin_destination(self, origin, destination, is_none_stop):
        '''
        find_flights_using_origin_destination returns matching flights based on an origin/destination pair.
        The returned results may include non-stop or one-stop flights.

        :param origin: the origin ICAO airport ID (e.g., KLAX, KSFO, KIAH, KHOU, KJFK, KEWR, KORD, KATL, etc.)
        :param destination: the destination ICAO airport ID (e.g., KLAX, KSFO, KIAH, KHOU, KJFK, KEWR, KORD, KATL, etc.)
        :param is_none_stop: True or False
        :return: list of matching flights on that route
        '''

        type = 'nonstop' if is_none_stop else 'onestop'
        cargo_airlines = ['FDX', 'VTS', 'UPS']

        if (self.is_production):
            itinerary = []
            payload = {'origin': origin, 'destination': destination, 'type': type, 'filter': 'airline'}
            response = self.__make_request("FindFlight", payload)

            for flight in response['FindFlightResult']['flights']:
                if flight['segments'][0]['progress_percent'] < 100:
                    cargo_airlines_found = False

                    for segment in flight['segments']:
                        if segment['airline'] in cargo_airlines:
                            cargo_airlines_found = True

                    if not cargo_airlines_found:
                        itinerary.append(flight)

            return itinerary
        else:
            return self.stubbed_find_flights_using_origin_destination_response


    def count_airport_operations(self, airport_code):
        '''
        count_airport_operations returns the number of aircraft scheduled, en route or departing the airport.
        Scheduled arrivals are non-airborne flights that are scheduled to fly to the airport in question.

        :param airport_code: the ICAO airport ID (e.g., KLAX, KSFO, KIAH, KHOU, KJFK, KEWR, KORD, KATL, etc.)
        :return: CountAirportOperationsStruct
        '''

        if(self.is_production):
            payload = {'airport_code': airport_code}
            return self.__make_request('CountAirportOperations', payload)
        else:
            return self.stubbed_count_aiport_operations_response


    def get_aircraft_type(self, aircraft_type):
        '''
        get_aircraft_type returns information about that type, comprising the manufacturer (for instance, "IAI"),
        type (for instance, "Gulfstream G200"), and description (like "twin-jet").

        :param aircraft_type: aircraft type ID
        :return: AircraftTypeStruct
        '''

        if (self.is_production):
            payload = {'type': aircraft_type}
            return self.__make_request('AircraftType', payload)
        else:
            return self.stubbed_get_aircraft_type_response


    def get_airport_info(self, airport_code):
        '''
        get_airport_info returns information about an airport given an airport code such as KLAX, KSFO, KORD, KIAH,
        O07, etc. Data returned includes name (Houston Intercontinental Airport), location
        (typically city, state and country code), latitude and longitude, alternate_ident (IATA, when available),
        timezone (:America/Chicago), elevation.

        :param airport_code: the ICAO airport ID (e.g., KLAX, KSFO, KIAH, KHOU, KJFK, KEWR, KORD, KATL, etc.)
        :return: AirportStruct
        '''

        if(self.is_production):
            payload = {'airport_code': airport_code}
            return self.__make_request('AirportInfo', payload)
        else:
            return self.stubbed_get_airport_info_response
